/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * Animations that can be played on a marker. Use the
 * <code>setAnimation</code>
 * 
 *  method on Marker or the 
 * <code>animation</code>
 * 
 * option to play an animation.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class Animation extends JavaScriptObject {

  /**
   * Marker bounces until animation is stopped.
   */ 
  public static final Animation BOUNCE = getBounce();

  /**
   * Marker falls from the top of the map ending with a small bounce.
   */ 
  public static final Animation DROP = getDrop();

  /**
   * Internal registry for value types.
   */ 
  private static Map<Double,Animation> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final Animation fromValue(double value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native Animation getBounce()/*-{
    var instance = { 'value' : $wnd.google.maps.Animation.BOUNCE };
    @com.google.maps.gwt.client.Animation::register(Lcom/google/maps/gwt/client/Animation;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native Animation getDrop()/*-{
    var instance = { 'value' : $wnd.google.maps.Animation.DROP };
    @com.google.maps.gwt.client.Animation::register(Lcom/google/maps/gwt/client/Animation;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(Animation value){
    if (registry == null) {
      registry = new HashMap<Double, Animation>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected Animation() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native double getValue()/*-{
    return this.value;
  }-*/;

}

