/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * Identifiers used to specify the placement of controls on the map.
 * Controls are positioned relative to other controls in the same layout
 * position.  Controls that are added first are positioned closer to the
 * edge of the map.
 * <code>
 * <br>&nbsp;&nbsp;+----------------+
 * <br>&nbsp;&nbsp;+&nbsp;TL&nbsp;&nbsp;&nbsp;&nbsp;TC&nbsp;&nbsp;&nbsp;&nbsp;TR +
 * <br>&nbsp;&nbsp;+&nbsp;LT&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;RT +
 * <br>&nbsp;&nbsp;+&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;+
 * <br>&nbsp;&nbsp;+&nbsp;LC&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;RC +
 * <br>&nbsp;&nbsp;+&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;+
 * <br>&nbsp;&nbsp;+&nbsp;LB&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;RB +
 * <br>&nbsp;&nbsp;+&nbsp;BL&nbsp;&nbsp;&nbsp;&nbsp;BC&nbsp;&nbsp;&nbsp;&nbsp;BR +
 * <br>&nbsp;&nbsp;+----------------+
 * <br></code>
 * 
 * Elements in the top or bottom row flow towards the middle. Elements
 * at the left or right sides flow downwards.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class ControlPosition extends JavaScriptObject {

  /**
   * Elements are positioned in the center of the bottom row.
   */ 
  public static final ControlPosition BOTTOM_CENTER = getBottomCenter();

  /**
   * Elements are positioned in the bottom left and flow towards the
   * middle.  Elements are positioned to the right of the Google logo.
   */ 
  public static final ControlPosition BOTTOM_LEFT = getBottomLeft();

  /**
   * Elements are positioned in the bottom right and flow towards the
   * middle.  Elements are positioned to the left of the copyrights.
   */ 
  public static final ControlPosition BOTTOM_RIGHT = getBottomRight();

  /**
   * Elements are positioned on the left, above bottom-left elements, and flow upwards.
   */ 
  public static final ControlPosition LEFT_BOTTOM = getLeftBottom();

  /**
   * Elements are positioned in the center of the left side.
   */ 
  public static final ControlPosition LEFT_CENTER = getLeftCenter();

  /**
   * Elements are positioned on the left, below top-left elements, and flow downwards.
   */ 
  public static final ControlPosition LEFT_TOP = getLeftTop();

  /**
   * Elements are positioned on the right, above bottom-right elements,
   * and flow upwards.
   */ 
  public static final ControlPosition RIGHT_BOTTOM = getRightBottom();

  /**
   * Elements are positioned in the center of the right side.
   */ 
  public static final ControlPosition RIGHT_CENTER = getRightCenter();

  /**
   * Elements are positioned on the right, below top-right elements, and flow downwards.
   */ 
  public static final ControlPosition RIGHT_TOP = getRightTop();

  /**
   * Elements are positioned in the center of the top row.
   */ 
  public static final ControlPosition TOP_CENTER = getTopCenter();

  /**
   * Elements are positioned in the top left and flow towards the middle.
   */ 
  public static final ControlPosition TOP_LEFT = getTopLeft();

  /**
   * Elements are positioned in the top right and flow towards the middle.
   */ 
  public static final ControlPosition TOP_RIGHT = getTopRight();

  /**
   * Internal registry for value types.
   */ 
  private static Map<Double,ControlPosition> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final ControlPosition fromValue(double value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native ControlPosition getBottomCenter()/*-{
    var instance = { 'value' : $wnd.google.maps.ControlPosition.BOTTOM_CENTER };
    @com.google.maps.gwt.client.ControlPosition::register(Lcom/google/maps/gwt/client/ControlPosition;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native ControlPosition getBottomLeft()/*-{
    var instance = { 'value' : $wnd.google.maps.ControlPosition.BOTTOM_LEFT };
    @com.google.maps.gwt.client.ControlPosition::register(Lcom/google/maps/gwt/client/ControlPosition;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native ControlPosition getBottomRight()/*-{
    var instance = { 'value' : $wnd.google.maps.ControlPosition.BOTTOM_RIGHT };
    @com.google.maps.gwt.client.ControlPosition::register(Lcom/google/maps/gwt/client/ControlPosition;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native ControlPosition getLeftBottom()/*-{
    var instance = { 'value' : $wnd.google.maps.ControlPosition.LEFT_BOTTOM };
    @com.google.maps.gwt.client.ControlPosition::register(Lcom/google/maps/gwt/client/ControlPosition;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native ControlPosition getLeftCenter()/*-{
    var instance = { 'value' : $wnd.google.maps.ControlPosition.LEFT_CENTER };
    @com.google.maps.gwt.client.ControlPosition::register(Lcom/google/maps/gwt/client/ControlPosition;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native ControlPosition getLeftTop()/*-{
    var instance = { 'value' : $wnd.google.maps.ControlPosition.LEFT_TOP };
    @com.google.maps.gwt.client.ControlPosition::register(Lcom/google/maps/gwt/client/ControlPosition;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native ControlPosition getRightBottom()/*-{
    var instance = { 'value' : $wnd.google.maps.ControlPosition.RIGHT_BOTTOM };
    @com.google.maps.gwt.client.ControlPosition::register(Lcom/google/maps/gwt/client/ControlPosition;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native ControlPosition getRightCenter()/*-{
    var instance = { 'value' : $wnd.google.maps.ControlPosition.RIGHT_CENTER };
    @com.google.maps.gwt.client.ControlPosition::register(Lcom/google/maps/gwt/client/ControlPosition;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native ControlPosition getRightTop()/*-{
    var instance = { 'value' : $wnd.google.maps.ControlPosition.RIGHT_TOP };
    @com.google.maps.gwt.client.ControlPosition::register(Lcom/google/maps/gwt/client/ControlPosition;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native ControlPosition getTopCenter()/*-{
    var instance = { 'value' : $wnd.google.maps.ControlPosition.TOP_CENTER };
    @com.google.maps.gwt.client.ControlPosition::register(Lcom/google/maps/gwt/client/ControlPosition;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native ControlPosition getTopLeft()/*-{
    var instance = { 'value' : $wnd.google.maps.ControlPosition.TOP_LEFT };
    @com.google.maps.gwt.client.ControlPosition::register(Lcom/google/maps/gwt/client/ControlPosition;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native ControlPosition getTopRight()/*-{
    var instance = { 'value' : $wnd.google.maps.ControlPosition.TOP_RIGHT };
    @com.google.maps.gwt.client.ControlPosition::register(Lcom/google/maps/gwt/client/ControlPosition;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(ControlPosition value){
    if (registry == null) {
      registry = new HashMap<Double, ControlPosition>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected ControlPosition() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native double getValue()/*-{
    return this.value;
  }-*/;

}

