/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.dom.client.Node;

/**
 * This object defines the properties that can be set on a
 * <code>DirectionsRenderer</code>
 * 
 * object.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class DirectionsRendererOptions extends JavaScriptObject {

  public static final DirectionsRendererOptions create(){
    return JavaScriptObject.createObject().cast();
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected DirectionsRendererOptions() {
    /* Java constructor is protected, */
  }

  /**
   * The directions to display on the map and/or in a
   * <code>&lt;div&gt;</code>
   * 
   * panel, retrieved as a
   * <code>DirectionsResult</code>
   * 
   *  object from 
   * <code>DirectionsService</code>
   * 
   * .
   */ 
  public final native void setDirections(DirectionsResult directions)/*-{
    this.directions = directions;
  }-*/;

  /**
   * If true, allows the user to drag and modify the paths of routes rendered by this 
   * <code>DirectionsRenderer</code>
   * 
   * .
   */ 
  public final native void setDraggable(boolean draggable)/*-{
    this.draggable = draggable;
  }-*/;

  /**
   * This property indicates whether the renderer should provide UI to
   * select amongst alternative routes.  By default, this flag is false
   * and a user-selectable list of routes will be shown in the directions'
   * associated panel.  To hide that list, set
   * <code>hideRouteList</code>
   * 
   * to
   * <code>true</code>
   * 
   * .
   */ 
  public final native void setHideRouteList(boolean hideRouteList)/*-{
    this.hideRouteList = hideRouteList;
  }-*/;

  /**
   * The 
   * <code>InfoWindow</code>
   * 
   * in which to render text information when a marker is clicked.
   * Existing info window content will be overwritten and its position
   * moved. If no info window is specified, the
   * <code>DirectionsRenderer</code>
   * 
   * will create and use its own info window. This property will be ignored if
   * <code>suppressInfoWindows</code>
   * 
   * is set to true.
   */ 
  public final native void setInfoWindow(InfoWindow infoWindow)/*-{
    this.infoWindow = infoWindow;
  }-*/;

  /**
   * Map on which to display the directions.
   */ 
  public final native void setMap(GoogleMap map)/*-{
    this.map = map;
  }-*/;

  /**
   * Options for the markers.  All markers rendered by the
   * <code>DirectionsRenderer</code>
   * 
   * will use these options.
   */ 
  public final native void setMarkerOptions(MarkerOptions markerOptions)/*-{
    var _markerOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _markerOptions = markerOptions;
    } else {
      _markerOptions = {};
      for(k in markerOptions) {
        if(k != "__gwt_ObjectId") {
          _markerOptions[k] = markerOptions[k];
        }
      }
    } 
    this.markerOptions = _markerOptions;
  }-*/;

  /**
   * The 
   * <code>&lt;div&gt;</code>
   * 
   * in which to display the directions steps.
   */ 
  public final native void setPanel(Node panel)/*-{
    this.panel = panel;
  }-*/;

  /**
   * Options for the polylines.  All polylines rendered by the
   * <code>DirectionsRenderer</code>
   * 
   * will use these options.
   */ 
  public final native void setPolylineOptions(PolylineOptions polylineOptions)/*-{
    var _polylineOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _polylineOptions = polylineOptions;
    } else {
      _polylineOptions = {};
      for(k in polylineOptions) {
        if(k != "__gwt_ObjectId") {
          _polylineOptions[k] = polylineOptions[k];
        }
      }
    } 
    this.polylineOptions = _polylineOptions;
  }-*/;

  /**
   * By default, the input map is centered and zoomed to the bounding box
   * of this set of directions. If this option is set to
   * <code>true</code>
   * 
   * , the viewport is left unchanged, unless the map's center and zoom were never set.
   */ 
  public final native void setPreserveViewport(boolean preserveViewport)/*-{
    this.preserveViewport = preserveViewport;
  }-*/;

  /**
   * The index of the route within the 
   * <code>DirectionsResult</code>
   * 
   * object.  The default value is 0.
   */ 
  public final native void setRouteIndex(double routeIndex)/*-{
    this.routeIndex = routeIndex;
  }-*/;

  /**
   * Suppress the rendering of the 
   * <code>BicyclingLayer</code>
   * 
   * when bicycling directions are requested.
   */ 
  public final native void setSuppressBicyclingLayer(boolean suppressBicyclingLayer)/*-{
    this.suppressBicyclingLayer = suppressBicyclingLayer;
  }-*/;

  /**
   * Suppress the rendering of info windows.
   */ 
  public final native void setSuppressInfoWindows(boolean suppressInfoWindows)/*-{
    this.suppressInfoWindows = suppressInfoWindows;
  }-*/;

  /**
   * Suppress the rendering of markers.
   */ 
  public final native void setSuppressMarkers(boolean suppressMarkers)/*-{
    this.suppressMarkers = suppressMarkers;
  }-*/;

  /**
   * Suppress the rendering of polylines.
   */ 
  public final native void setSuppressPolylines(boolean suppressPolylines)/*-{
    this.suppressPolylines = suppressPolylines;
  }-*/;

}

