/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArray;

/**
 * A directions query to be sent to the
 * <code><a href="#DirectionsService">DirectionsService</a></code>
 * 
 * .
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class DirectionsRequest extends JavaScriptObject {

  public static final DirectionsRequest create(){
    return JavaScriptObject.createObject().cast();
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected DirectionsRequest() {
    /* Java constructor is protected, */
  }

  /**
   * If true, instructs the Directions service to avoid highways where
   * possible. Optional.
   */ 
  public final native void setAvoidHighways(boolean avoidHighways)/*-{
    this.avoidHighways = avoidHighways;
  }-*/;

  /**
   * If true, instructs the Directions service to avoid toll roads where
   * possible. Optional.
   */ 
  public final native void setAvoidTolls(boolean avoidTolls)/*-{
    this.avoidTolls = avoidTolls;
  }-*/;

  /**
   * Location of destination. This can be specified as either a string to
   * be geocoded or a
   * <code>LatLng</code>
   * 
   * . Required.
   */ 
  public final native void setDestination(LatLng destination)/*-{
    this.destination = destination;
  }-*/;

  /**
   * Location of destination. This can be specified as either a string to
   * be geocoded or a
   * <code>LatLng</code>
   * 
   * . Required.
   */ 
  public final native void setDestination(String destination)/*-{
    this.destination = destination;
  }-*/;

  /**
   * If set to true, the 
   * <code>DirectionService</code>
   * 
   * will attempt to re-order the supplied intermediate waypoints to
   * minimize overall cost of the route. If waypoints are optimized,
   * inspect
   * <code>DirectionsRoute.waypoint_order</code>
   * 
   * in the response to determine the new ordering.
   */ 
  public final native void setOptimizeWaypoints(boolean optimizeWaypoints)/*-{
    this.optimizeWaypoints = optimizeWaypoints;
  }-*/;

  /**
   * Location of origin. This can be specified as either a string to be geocoded or a 
   * <code>LatLng</code>
   * 
   * . Required.
   */ 
  public final native void setOrigin(LatLng origin)/*-{
    this.origin = origin;
  }-*/;

  /**
   * Location of origin. This can be specified as either a string to be geocoded or a 
   * <code>LatLng</code>
   * 
   * . Required.
   */ 
  public final native void setOrigin(String origin)/*-{
    this.origin = origin;
  }-*/;

  /**
   * Whether or not route alternatives should be provided. Optional.
   */ 
  public final native void setProvideRouteAlternatives(boolean provideRouteAlternatives)/*-{
    this.provideRouteAlternatives = provideRouteAlternatives;
  }-*/;

  /**
   * Region code used as a bias for geocoding requests. Optional.
   */ 
  public final native void setRegion(String region)/*-{
    this.region = region;
  }-*/;

  /**
   * Type of routing requested. Required.
   */ 
  public final native void setTravelMode(TravelMode travelMode)/*-{
    var _travelMode = travelMode == undefined ? null : travelMode.value; 
    this.travelMode = _travelMode;
  }-*/;

  /**
   * Preferred unit system to use when displaying distance. Defaults to
   * the unit system used in the country of origin.
   */ 
  public final native void setUnitSystem(UnitSystem unitSystem)/*-{
    var _unitSystem = unitSystem == undefined ? null : unitSystem.value; 
    this.unitSystem = _unitSystem;
  }-*/;

  /**
   * Array of intermediate waypoints. Directions will be calculated from
   * the origin to the destination by way of each waypoint in this array.
   * Optional.
   */ 
  public final native void setWaypoints(JsArray<DirectionsWaypoint> waypoints)/*-{
    this.waypoints = waypoints;
  }-*/;

}

