/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArray;
import com.google.gwt.core.client.JsArrayNumber;
import com.google.gwt.core.client.JsArrayString;

/**
 * A single route containing a set of legs in a
 * <code><a href="#DirectionsResult">DirectionsResult</a></code>
 * 
 * . (This object was formerly known as "DirectionsTrip".) Note that
 * though this object is "JSON-like," it is not strictly JSON, as it
 * directly and indirectly includes
 * <code>LatLng</code>
 * 
 * objects.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class DirectionsRoute extends JavaScriptObject {


  /**
   * Protected constructor avoids default public constructor.
   */
  protected DirectionsRoute() {
    /* Java constructor is protected, */
  }

  /**
   * The bounds for this route.
   */ 
  public final native LatLngBounds getBounds()/*-{
    return this.bounds;

  }-*/;

  /**
   * Copyrights text to be displayed for this route.
   */ 
  public final native String getCopyrights()/*-{
    return this.copyrights;

  }-*/;

  /**
   * An array of 
   * <code>DirectionsLeg</code>
   * 
   * s, each of which contains information about the steps of which it is
   * composed.  There will be one leg for each waypoint or destination
   * specified.  So a route with no waypoints will contain one
   * <code>DirectionsLeg</code>
   * 
   * and a route with one waypoint will contain two. (This property was
   * formerly known as "routes".)
   */ 
  public final native JsArray<DirectionsLeg> getLegs()/*-{
    return this.legs;

  }-*/;

  /**
   * An array of 
   * <code>LatLng</code>
   * 
   * s representing the entire course of this route. The path is
   * simplified in order to make it suitable in contexts where a small
   * number of vertices is required (such as Static Maps API URLs).
   */ 
  public final native JsArray<LatLng> getOverviewPath()/*-{
    return this.overview_path;

  }-*/;

  /**
   * Warnings to be displayed when showing these directions.
   */ 
  public final native JsArrayString getWarnings()/*-{
    return this.warnings;

  }-*/;

  /**
   * If 
   * <code>optimizeWaypoints</code>
   * 
   *  was set to 
   * <code>true</code>
   * 
   * , this field will contain the re-ordered permutation of the input
   * waypoints. For example, if the input was:<br> &nbsp;&nbsp;Origin: Los
   * Angeles<br> &nbsp;&nbsp;Waypoints: Dallas, Bangor, Phoenix<br>
   * &nbsp;&nbsp;Destination: New York<br> and the optimized output was
   * ordered as follows:<br> &nbsp;&nbsp;Origin: Los Angeles<br>
   * &nbsp;&nbsp;Waypoints: Phoenix, Dallas, Bangor<br>
   * &nbsp;&nbsp;Destination: New York<br> then this field will be an
   * <code>Array</code>
   * 
   * containing the values [2, 0, 1].  Note that the numbering of
   * waypoints is zero-based.<br> If any of the input waypoints has
   * <code>stopover</code>
   * 
   * set to
   * <code>false</code>
   * 
   * , this field will be empty, since route optimization is not available
   * for such queries.
   */ 
  public final native JsArrayNumber getWaypointOrder()/*-{
    return this.waypoint_order;

  }-*/;

  /**
   * The bounds for this route.
   */ 
  public final native void setBounds(LatLngBounds bounds)/*-{
    this.bounds = bounds;
  }-*/;

  /**
   * Copyrights text to be displayed for this route.
   */ 
  public final native void setCopyrights(String copyrights)/*-{
    this.copyrights = copyrights;
  }-*/;

  /**
   * An array of 
   * <code>DirectionsLeg</code>
   * 
   * s, each of which contains information about the steps of which it is
   * composed.  There will be one leg for each waypoint or destination
   * specified.  So a route with no waypoints will contain one
   * <code>DirectionsLeg</code>
   * 
   * and a route with one waypoint will contain two. (This property was
   * formerly known as "routes".)
   */ 
  public final native void setLegs(JsArray<DirectionsLeg> legs)/*-{
    this.legs = legs;
  }-*/;

  /**
   * An array of 
   * <code>LatLng</code>
   * 
   * s representing the entire course of this route. The path is
   * simplified in order to make it suitable in contexts where a small
   * number of vertices is required (such as Static Maps API URLs).
   */ 
  public final native void setOverviewPath(JsArray<LatLng> overview_path)/*-{
    this.overview_path = overview_path;
  }-*/;

  /**
   * Warnings to be displayed when showing these directions.
   */ 
  public final native void setWarnings(JsArrayString warnings)/*-{
    this.warnings = warnings;
  }-*/;

  /**
   * If 
   * <code>optimizeWaypoints</code>
   * 
   *  was set to 
   * <code>true</code>
   * 
   * , this field will contain the re-ordered permutation of the input
   * waypoints. For example, if the input was:<br> &nbsp;&nbsp;Origin: Los
   * Angeles<br> &nbsp;&nbsp;Waypoints: Dallas, Bangor, Phoenix<br>
   * &nbsp;&nbsp;Destination: New York<br> and the optimized output was
   * ordered as follows:<br> &nbsp;&nbsp;Origin: Los Angeles<br>
   * &nbsp;&nbsp;Waypoints: Phoenix, Dallas, Bangor<br>
   * &nbsp;&nbsp;Destination: New York<br> then this field will be an
   * <code>Array</code>
   * 
   * containing the values [2, 0, 1].  Note that the numbering of
   * waypoints is zero-based.<br> If any of the input waypoints has
   * <code>stopover</code>
   * 
   * set to
   * <code>false</code>
   * 
   * , this field will be empty, since route optimization is not available
   * for such queries.
   */ 
  public final native void setWaypointOrder(JsArrayNumber waypoint_order)/*-{
    this.waypoint_order = waypoint_order;
  }-*/;

}

