/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArray;
import com.google.gwt.core.client.JsArrayString;

/**
 * A distance matrix query sent by the 
 * <code>DistanceMatrixService</code>
 * 
 * containing arrays of origin and destination locations, and various
 * options for computing metrics.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class DistanceMatrixRequest extends JavaScriptObject {

  public static final DistanceMatrixRequest create(){
    return JavaScriptObject.createObject().cast();
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected DistanceMatrixRequest() {
    /* Java constructor is protected, */
  }

  /**
   * If true, instructs the Distance Matrix service to avoid highways
   * where possible. Optional.
   */ 
  public final native void setAvoidHighways(boolean avoidHighways)/*-{
    this.avoidHighways = avoidHighways;
  }-*/;

  /**
   * If true, instructs the Distance Matrix service to avoid toll roads
   * where possible. Optional.
   */ 
  public final native void setAvoidTolls(boolean avoidTolls)/*-{
    this.avoidTolls = avoidTolls;
  }-*/;

  /**
   * An array containing destination address strings and/or
   * <code>LatLng</code>
   * 
   * s, to which to calculate distance and time. Required.
   */ 
  public final native void setDestinations(JsArray<LatLng> destinations)/*-{
    this.destinations = destinations;
  }-*/;

  /**
   * An array containing destination address strings and/or
   * <code>LatLng</code>
   * 
   * s, to which to calculate distance and time. Required.
   */ 
  public final native void setDestinations(JsArrayString destinations)/*-{
    this.destinations = destinations;
  }-*/;

  /**
   * An array containing origin address strings and/or 
   * <code>LatLng</code>
   * 
   * s, from which to calculate distance and time. Required.
   */ 
  public final native void setOrigins(JsArray<LatLng> origins)/*-{
    this.origins = origins;
  }-*/;

  /**
   * An array containing origin address strings and/or 
   * <code>LatLng</code>
   * 
   * s, from which to calculate distance and time. Required.
   */ 
  public final native void setOrigins(JsArrayString origins)/*-{
    this.origins = origins;
  }-*/;

  /**
   * Region code used as a bias for geocoding requests. Optional.
   */ 
  public final native void setRegion(String region)/*-{
    this.region = region;
  }-*/;

  /**
   * Type of routing requested. Required.
   */ 
  public final native void setTravelMode(TravelMode travelMode)/*-{
    var _travelMode = travelMode == undefined ? null : travelMode.value; 
    this.travelMode = _travelMode;
  }-*/;

  /**
   * Preferred unit system to use when displaying distance. Optional;
   * defaults to metric.
   */ 
  public final native void setUnitSystem(UnitSystem unitSystem)/*-{
    var _unitSystem = unitSystem == undefined ? null : unitSystem.value; 
    this.unitSystem = _unitSystem;
  }-*/;

}

