/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * The top-level status about the request in general returned by the
 * <code>DistanceMatrixService</code>
 * 
 * upon completion of a distance matrix request.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class DistanceMatrixStatus extends JavaScriptObject {

  /**
   * The 
   * <code>KmlLayer</code>
   * 
   * is invalid.
   */ 
  public static final DistanceMatrixStatus INVALID_REQUEST = getInvalidRequest();

  /**
   * The request contains more than 25 origins, or more than 25 destinations.
   */ 
  public static final DistanceMatrixStatus MAX_DIMENSIONS_EXCEEDED = getMaxDimensionsExceeded();

  /**
   * The product of origins and destinations exceeds the per-query limit.
   */ 
  public static final DistanceMatrixStatus MAX_ELEMENTS_EXCEEDED = getMaxElementsExceeded();

  /**
   * The request was successful.
   */ 
  public static final DistanceMatrixStatus OK = getOk();

  /**
   * The webpage has gone over the requests limit in too short a period of time.
   */ 
  public static final DistanceMatrixStatus OVER_QUERY_LIMIT = getOverQueryLimit();

  /**
   * The webpage is not allowed to use the geocoder.
   */ 
  public static final DistanceMatrixStatus REQUEST_DENIED = getRequestDenied();

  /**
   * The request could not be successfully processed, yet the exact reason
   * for failure is unknown.
   */ 
  public static final DistanceMatrixStatus UNKNOWN_ERROR = getUnknownError();

  /**
   * Internal registry for value types.
   */ 
  private static Map<String,DistanceMatrixStatus> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final DistanceMatrixStatus fromValue(String value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native DistanceMatrixStatus getInvalidRequest()/*-{
    var instance = { 'value' : $wnd.google.maps.DistanceMatrixStatus.INVALID_REQUEST };
    @com.google.maps.gwt.client.DistanceMatrixStatus::register(Lcom/google/maps/gwt/client/DistanceMatrixStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native DistanceMatrixStatus getMaxDimensionsExceeded()/*-{
    var instance = { 'value' : $wnd.google.maps.DistanceMatrixStatus.MAX_DIMENSIONS_EXCEEDED };
    @com.google.maps.gwt.client.DistanceMatrixStatus::register(Lcom/google/maps/gwt/client/DistanceMatrixStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native DistanceMatrixStatus getMaxElementsExceeded()/*-{
    var instance = { 'value' : $wnd.google.maps.DistanceMatrixStatus.MAX_ELEMENTS_EXCEEDED };
    @com.google.maps.gwt.client.DistanceMatrixStatus::register(Lcom/google/maps/gwt/client/DistanceMatrixStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native DistanceMatrixStatus getOk()/*-{
    var instance = { 'value' : $wnd.google.maps.DistanceMatrixStatus.OK };
    @com.google.maps.gwt.client.DistanceMatrixStatus::register(Lcom/google/maps/gwt/client/DistanceMatrixStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native DistanceMatrixStatus getOverQueryLimit()/*-{
    var instance = { 'value' : $wnd.google.maps.DistanceMatrixStatus.OVER_QUERY_LIMIT };
    @com.google.maps.gwt.client.DistanceMatrixStatus::register(Lcom/google/maps/gwt/client/DistanceMatrixStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native DistanceMatrixStatus getRequestDenied()/*-{
    var instance = { 'value' : $wnd.google.maps.DistanceMatrixStatus.REQUEST_DENIED };
    @com.google.maps.gwt.client.DistanceMatrixStatus::register(Lcom/google/maps/gwt/client/DistanceMatrixStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native DistanceMatrixStatus getUnknownError()/*-{
    var instance = { 'value' : $wnd.google.maps.DistanceMatrixStatus.UNKNOWN_ERROR };
    @com.google.maps.gwt.client.DistanceMatrixStatus::register(Lcom/google/maps/gwt/client/DistanceMatrixStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(DistanceMatrixStatus value){
    if (registry == null) {
      registry = new HashMap<String, DistanceMatrixStatus>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected DistanceMatrixStatus() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native String getValue()/*-{
    return this.value;
  }-*/;

}

