/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * Describes the type of location returned from a geocode.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class GeocoderLocationType extends JavaScriptObject {

  /**
   * The returned result is approximate.
   */ 
  public static final GeocoderLocationType APPROXIMATE = getApproximate();

  /**
   * The returned result is the geometric center of a result such a line
   * (e.g. street) or polygon (region).
   */ 
  public static final GeocoderLocationType GEOMETRIC_CENTER = getGeometricCenter();

  /**
   * The returned result reflects an approximation (usually on a road)
   * interpolated between two precise points (such as intersections).
   * Interpolated results are generally returned when rooftop geocodes are
   * unavilable for a street address.
   */ 
  public static final GeocoderLocationType RANGE_INTERPOLATED = getRangeInterpolated();

  /**
   * The returned result reflects a precise geocode.
   */ 
  public static final GeocoderLocationType ROOFTOP = getRooftop();

  /**
   * Internal registry for value types.
   */ 
  private static Map<String,GeocoderLocationType> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final GeocoderLocationType fromValue(String value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native GeocoderLocationType getApproximate()/*-{
    var instance = { 'value' : $wnd.google.maps.GeocoderLocationType.APPROXIMATE };
    @com.google.maps.gwt.client.GeocoderLocationType::register(Lcom/google/maps/gwt/client/GeocoderLocationType;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native GeocoderLocationType getGeometricCenter()/*-{
    var instance = { 'value' : $wnd.google.maps.GeocoderLocationType.GEOMETRIC_CENTER };
    @com.google.maps.gwt.client.GeocoderLocationType::register(Lcom/google/maps/gwt/client/GeocoderLocationType;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native GeocoderLocationType getRangeInterpolated()/*-{
    var instance = { 'value' : $wnd.google.maps.GeocoderLocationType.RANGE_INTERPOLATED };
    @com.google.maps.gwt.client.GeocoderLocationType::register(Lcom/google/maps/gwt/client/GeocoderLocationType;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native GeocoderLocationType getRooftop()/*-{
    var instance = { 'value' : $wnd.google.maps.GeocoderLocationType.ROOFTOP };
    @com.google.maps.gwt.client.GeocoderLocationType::register(Lcom/google/maps/gwt/client/GeocoderLocationType;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(GeocoderLocationType value){
    if (registry == null) {
      registry = new HashMap<String, GeocoderLocationType>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected GeocoderLocationType() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native String getValue()/*-{
    return this.value;
  }-*/;

}

