/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * The status returned by the 
 * <code>Geocoder</code>
 * 
 * on the completion of a call to 
 * <code>geocode()</code>
 * 
 * .
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class GeocoderStatus extends JavaScriptObject {

  /**
   * There was a problem contacting the Google servers.
   */ 
  public static final GeocoderStatus ERROR = getError();

  /**
   * The 
   * <code>KmlLayer</code>
   * 
   * is invalid.
   */ 
  public static final GeocoderStatus INVALID_REQUEST = getInvalidRequest();

  /**
   * The request was successful.
   */ 
  public static final GeocoderStatus OK = getOk();

  /**
   * The webpage has gone over the requests limit in too short a period of time.
   */ 
  public static final GeocoderStatus OVER_QUERY_LIMIT = getOverQueryLimit();

  /**
   * The webpage is not allowed to use the geocoder.
   */ 
  public static final GeocoderStatus REQUEST_DENIED = getRequestDenied();

  /**
   * The request could not be successfully processed, yet the exact reason
   * for failure is unknown.
   */ 
  public static final GeocoderStatus UNKNOWN_ERROR = getUnknownError();

  /**
   * There are no nearby panoramas.
   */ 
  public static final GeocoderStatus ZERO_RESULTS = getZeroResults();

  /**
   * Internal registry for value types.
   */ 
  private static Map<String,GeocoderStatus> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final GeocoderStatus fromValue(String value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native GeocoderStatus getError()/*-{
    var instance = { 'value' : $wnd.google.maps.GeocoderStatus.ERROR };
    @com.google.maps.gwt.client.GeocoderStatus::register(Lcom/google/maps/gwt/client/GeocoderStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native GeocoderStatus getInvalidRequest()/*-{
    var instance = { 'value' : $wnd.google.maps.GeocoderStatus.INVALID_REQUEST };
    @com.google.maps.gwt.client.GeocoderStatus::register(Lcom/google/maps/gwt/client/GeocoderStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native GeocoderStatus getOk()/*-{
    var instance = { 'value' : $wnd.google.maps.GeocoderStatus.OK };
    @com.google.maps.gwt.client.GeocoderStatus::register(Lcom/google/maps/gwt/client/GeocoderStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native GeocoderStatus getOverQueryLimit()/*-{
    var instance = { 'value' : $wnd.google.maps.GeocoderStatus.OVER_QUERY_LIMIT };
    @com.google.maps.gwt.client.GeocoderStatus::register(Lcom/google/maps/gwt/client/GeocoderStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native GeocoderStatus getRequestDenied()/*-{
    var instance = { 'value' : $wnd.google.maps.GeocoderStatus.REQUEST_DENIED };
    @com.google.maps.gwt.client.GeocoderStatus::register(Lcom/google/maps/gwt/client/GeocoderStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native GeocoderStatus getUnknownError()/*-{
    var instance = { 'value' : $wnd.google.maps.GeocoderStatus.UNKNOWN_ERROR };
    @com.google.maps.gwt.client.GeocoderStatus::register(Lcom/google/maps/gwt/client/GeocoderStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native GeocoderStatus getZeroResults()/*-{
    var instance = { 'value' : $wnd.google.maps.GeocoderStatus.ZERO_RESULTS };
    @com.google.maps.gwt.client.GeocoderStatus::register(Lcom/google/maps/gwt/client/GeocoderStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(GeocoderStatus value){
    if (registry == null) {
      registry = new HashMap<String, GeocoderStatus>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected GeocoderStatus() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native String getValue()/*-{
    return this.value;
  }-*/;

}

