/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArray;
import com.google.gwt.dom.client.Node;

/**
 * 
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class GoogleMap extends MVCObject {

  /**
   * This event is fired when the viewport bounds have changed.
   */
  public interface BoundsChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the map center property changes.
   */
  public interface CenterChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the user clicks on the map (but not when
   * they click on a marker or infowindow).
   */
  public interface ClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the user double-clicks on the map. Note that
   * the click event will also fire, right before this one.
   */
  public interface DblClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the user stops dragging the map.
   */
  public interface DragEndHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is repeatedly fired while the user drags the map.
   */
  public interface DragHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the user starts dragging the map.
   */
  public interface DragStartHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the map heading property changes.
   */
  public interface HeadingChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the map becomes idle after panning or zooming.
   */
  public interface IdleHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the mapTypeId property changes.
   */
  public interface MapTypeIdChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired whenever the user's mouse moves over the map container.
   */
  public interface MouseMoveHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the user's mouse exits the map container.
   */
  public interface MouseOutHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the user's mouse enters the map container.
   */
  public interface MouseOverHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the projection has changed.
   */
  public interface ProjectionChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * Developers should trigger this event on the map when the div changes size: 
   * <code><a href="#event">google.maps.event.trigger</a>(map, 'resize')
   * </code>
   * 
   * .
   */
  public interface ResizeHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the DOM contextmenu event is fired on the map container.
   */
  public interface RightClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the visible tiles have finished loading.
   */
  public interface TilesLoadedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the map tilt property changes.
   */
  public interface TiltChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the map zoom property changes.
   */
  public interface ZoomChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * Creates a new map inside of the given HTML container, which is typically a 
   * <code>DIV</code>
   * 
   * element.
   */ 
  public static native GoogleMap create(Node mapDiv, MapOptions opts)/*-{
    var _opts;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _opts = opts;
    } else {
      _opts = {};
      for(k in opts) {
        if(k != "__gwt_ObjectId") {
          _opts[k] = opts[k];
        }
      }
    } 
    return new $wnd.google.maps.Map(mapDiv, _opts);
  }-*/;

  /**
   * Creates a new map inside of the given HTML container, which is typically a 
   * <code>DIV</code>
   * 
   * element.
   */ 
  public static native GoogleMap create(Node mapDiv)/*-{
    return new $wnd.google.maps.Map(mapDiv);
  }-*/;


  /**
   * Protected constructor avoids default public constructor.
   */
  protected GoogleMap() {
    /* Java constructor is protected, */
  }

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addBoundsChangedListener(BoundsChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.BoundsChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "bounds_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addBoundsChangedListenerOnce(BoundsChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.BoundsChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "bounds_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addCenterChangedListener(CenterChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.CenterChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "center_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addCenterChangedListenerOnce(CenterChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.CenterChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "center_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addClickListener(ClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GoogleMap.ClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "click", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addClickListenerOnce(ClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GoogleMap.ClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "click", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addDblClickListener(DblClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GoogleMap.DblClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "dblclick", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addDblClickListenerOnce(DblClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GoogleMap.DblClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "dblclick", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addDragEndListener(DragEndHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.DragEndHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "dragend", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addDragEndListenerOnce(DragEndHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.DragEndHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "dragend", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addDragListener(DragHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.DragHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "drag", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addDragListenerOnce(DragHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.DragHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "drag", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addDragStartListener(DragStartHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.DragStartHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "dragstart", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addDragStartListenerOnce(DragStartHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.DragStartHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "dragstart", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addHeadingChangedListener(HeadingChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.HeadingChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "heading_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addHeadingChangedListenerOnce(HeadingChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.HeadingChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "heading_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addIdleListener(IdleHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.IdleHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "idle", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addIdleListenerOnce(IdleHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.IdleHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "idle", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMapTypeIdChangedListener(MapTypeIdChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.MapTypeIdChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "maptypeid_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMapTypeIdChangedListenerOnce(MapTypeIdChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.MapTypeIdChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "maptypeid_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseMoveListener(MouseMoveHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GoogleMap.MouseMoveHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mousemove", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseMoveListenerOnce(MouseMoveHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GoogleMap.MouseMoveHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mousemove", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseOutListener(MouseOutHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GoogleMap.MouseOutHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mouseout", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseOutListenerOnce(MouseOutHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GoogleMap.MouseOutHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mouseout", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseOverListener(MouseOverHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GoogleMap.MouseOverHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mouseover", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseOverListenerOnce(MouseOverHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GoogleMap.MouseOverHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mouseover", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addProjectionChangedListener(ProjectionChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.ProjectionChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "projection_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addProjectionChangedListenerOnce(ProjectionChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.ProjectionChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "projection_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addResizeListener(ResizeHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.ResizeHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "resize", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addResizeListenerOnce(ResizeHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.ResizeHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "resize", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addRightClickListener(RightClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GoogleMap.RightClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "rightclick", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addRightClickListenerOnce(RightClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GoogleMap.RightClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "rightclick", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addTilesLoadedListener(TilesLoadedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.TilesLoadedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "tilesloaded", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addTilesLoadedListenerOnce(TilesLoadedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.TilesLoadedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "tilesloaded", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addTiltChangedListener(TiltChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.TiltChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "tilt_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addTiltChangedListenerOnce(TiltChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.TiltChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "tilt_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addZoomChangedListener(ZoomChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.ZoomChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "zoom_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addZoomChangedListenerOnce(ZoomChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.GoogleMap.ZoomChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "zoom_changed", _handler);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearBoundsChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "bounds_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearCenterChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "center_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "click");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearDblClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "dblclick");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearDragEndListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "dragend");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearDragListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "drag");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearDragStartListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "dragstart");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearHeadingChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "heading_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearIdleListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "idle");
  }-*/;

  /**
   * Removes all listeners for all events for the given instance.
   */ 
  public final native void clearInstanceListeners()/*-{
    $wnd.google.maps.event.clearInstanceListeners(this);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMapTypeIdChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "maptypeid_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseMoveListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mousemove");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseOutListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mouseout");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseOverListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mouseover");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearProjectionChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "projection_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearResizeListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "resize");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearRightClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "rightclick");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearTilesLoadedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "tilesloaded");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearTiltChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "tilt_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearZoomChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "zoom_changed");
  }-*/;

  /**
   * Sets the viewport to contain the given bounds.
   */ 
  public final native void fitBounds(LatLngBounds bounds)/*-{
    this.fitBounds(bounds);

  }-*/;

  /**
   * Returns the lat/lng bounds of the current viewport. If the map is not
   * yet initialized (i.e. the mapType is still null), or center and zoom
   * have not been set then the result is
   * <code>null</code>
   * 
   * or
   * <code>undefined</code>
   * 
   * .
   */ 
  public final native LatLngBounds getBounds()/*-{
    return this.getBounds();

  }-*/;

  /**
   * Returns the position displayed at the center of the map. Note that this
   * <code>LatLng</code>
   * 
   * object is <em>not</em> wrapped. See
   * <code><a href="#LatLng">LatLng</a></code>
   * 
   * for more information.
   */ 
  public final native LatLng getCenter()/*-{
    return this.getCenter();

  }-*/;

  /**
   * Additional controls to attach to the map. To add a control to the
   * map, add the control's
   * <code>&lt;div&gt;</code>
   * 
   *  to the 
   * <code>MVCArray</code>
   * 
   * corresponding to the 
   * <code>ControlPosition</code>
   * 
   * where it should be rendered.
   */ 
  public final native JsArray<MVCArray<Node>> getControls()/*-{
    return this.controls;

  }-*/;

  public final native Node getDiv()/*-{
    return this.getDiv();

  }-*/;

  public final native MapFeaturesTracker getFeatures()/*-{
    return this.features;

  }-*/;

  /**
   * Returns the compass heading of aerial imagery.  The heading value is
   * measured in degrees (clockwise) from cardinal direction North.
   */ 
  public final native double getHeading()/*-{
    return this.getHeading();

  }-*/;

  /**
   * A registry of 
   * <code>MapType</code>
   * 
   * instances by string ID.
   */ 
  public final native MapTypeRegistry getMapTypes()/*-{
    return this.mapTypes;

  }-*/;

  /**
   * Additional map types to overlay.
   */ 
  public final native MVCArray<MapType> getOverlayMapTypes()/*-{
    return this.overlayMapTypes;

  }-*/;

  /**
   * Returns the current 
   * <code>Projection</code>
   * 
   * .  If the map is not yet initialized (i.e. the mapType is still null)
   * then the result is null. Listen to
   * <code>projection_changed</code>
   * 
   * and check its value to ensure it is not null.
   */ 
  public final native Projection getProjection()/*-{
    return this.getProjection();

  }-*/;

  /**
   * Returns the default 
   * <code>StreetViewPanorama</code>
   * 
   * bound to the map, which may be a default panorama embedded within the
   * map, or the panorama set using
   * <code>setStreetView()</code>
   * 
   * . Changes to the map's 
   * <code>streetViewControl</code>
   * 
   * will be reflected in the display of such a bound panorama.
   */ 
  public final native StreetViewPanorama getStreetView()/*-{
    return this.getStreetView();

  }-*/;

  /**
   * Returns the angle of incidence for aerial imagery (available for
   * <code>SATELLITE</code>
   * 
   *  and 
   * <code>HYBRID</code>
   * 
   * map types) measured in degrees from the viewport plane to the map
   * plane.  A value of
   * <code>0</code>
   * 
   * indicates no angle of incidence (no tilt) while 45&deg; imagery will
   * return a value of
   * <code>45</code>
   * 
   * .
   */ 
  public final native double getTilt()/*-{
    return this.getTilt();

  }-*/;

  public final native double getZoom()/*-{
    return this.getZoom();

  }-*/;

  /**
   * Changes the center of the map by the given distance in pixels.  If
   * the distance is less than both the width and height of the map, the
   * transition will be smoothly animated.  Note that the map coordinate
   * system increases from west to east (for x values) and north to south
   * (for y values).
   */ 
  public final native void panBy(double x, double y)/*-{
    this.panBy(x, y);

  }-*/;

  /**
   * Changes the center of the map to the given 
   * <code>LatLng</code>
   * 
   * .  If the change is less than both the width and height of the map,
   * the transition will be smoothly animated.
   */ 
  public final native void panTo(LatLng latLng)/*-{
    this.panTo(latLng);

  }-*/;

  /**
   * Pans the map by the minimum amount necessary to contain the given
   * <code>LatLngBounds</code>
   * 
   * .  It makes no guarantee where on the map the bounds will be, except
   * that as much of the bounds as possible will be visible.  The bounds
   * will be positioned inside the area bounded by the map type and
   * navigation (pan, zoom, and Street View) controls, if they are present
   * on the map.  If the bounds is larger than the map, the map will be
   * shifted to include the northwest corner of the bounds.  If the change
   * in the map's position is less than both the width and height of the
   * map, the transition will be smoothly animated.
   */ 
  public final native void panToBounds(LatLngBounds latLngBounds)/*-{
    this.panToBounds(latLngBounds);

  }-*/;

  public final native void setCenter(LatLng latlng)/*-{
    this.setCenter(latlng);

  }-*/;

  /**
   * Additional controls to attach to the map. To add a control to the
   * map, add the control's
   * <code>&lt;div&gt;</code>
   * 
   *  to the 
   * <code>MVCArray</code>
   * 
   * corresponding to the 
   * <code>ControlPosition</code>
   * 
   * where it should be rendered.
   */ 
  public final native void setControls(JsArray<MVCArray<Node>> controls)/*-{
    this.controls = controls;
  }-*/;

  public final native void setFeatures(MapFeaturesTracker features)/*-{
    this.features = features;
  }-*/;

  /**
   * Sets the compass heading for aerial imagery measured in degrees from
   * cardinal direction North.
   */ 
  public final native void setHeading(double heading)/*-{
    this.setHeading(heading);

  }-*/;

  public final native void setMapTypeId(MapTypeId mapTypeId)/*-{
    var _mapTypeId = mapTypeId == undefined ? null : mapTypeId.value; 
    this.setMapTypeId(_mapTypeId);

  }-*/;

  public final native void setMapTypeId(String mapTypeId)/*-{
    this.setMapTypeId(mapTypeId);

  }-*/;

  /**
   * A registry of 
   * <code>MapType</code>
   * 
   * instances by string ID.
   */ 
  public final native void setMapTypes(MapTypeRegistry mapTypes)/*-{
    this.mapTypes = mapTypes;
  }-*/;

  public final native void setOptions(MapOptions options)/*-{
    var _options;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _options = options;
    } else {
      _options = {};
      for(k in options) {
        if(k != "__gwt_ObjectId") {
          _options[k] = options[k];
        }
      }
    } 
    this.setOptions(_options);

  }-*/;

  /**
   * Additional map types to overlay.
   */ 
  public final native void setOverlayMapTypes(MVCArray<MapType> overlayMapTypes)/*-{
    this.overlayMapTypes = overlayMapTypes;
  }-*/;

  /**
   * Binds a 
   * <code>StreetViewPanorama</code>
   * 
   * to the map. This panorama overrides the default 
   * <code>StreetViewPanorama</code>
   * 
   * , allowing the map to bind to an external panorama outside of the
   * map. Setting the panorama to
   * <code>null</code>
   * 
   * binds the default embedded panorama back to the map.
   */ 
  public final native void setStreetView(StreetViewPanorama panorama)/*-{
    this.setStreetView(panorama);

  }-*/;

  /**
   * Sets the angle of incidence for aerial imagery (available for
   * <code>SATELLITE</code>
   * 
   *  and 
   * <code>HYBRID</code>
   * 
   * map types) measured in degrees from the viewport plane to the map
   * plane.  The only supported values are
   * <code>0</code>
   * 
   * , indicating no angle of incidence (no tilt), and
   * <code>45</code>
   * 
   * indicating a tilt of 45deg;.
   */ 
  public final native void setTilt(double tilt)/*-{
    this.setTilt(tilt);

  }-*/;

  public final native void setZoom(double zoom)/*-{
    this.setZoom(zoom);

  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerBoundsChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "bounds_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerCenterChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "center_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "click", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerDblClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "dblclick", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerDrag(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "drag", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerDragEnd(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "dragend", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerDragStart(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "dragstart", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerHeadingChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "heading_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerIdle(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "idle", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMapTypeIdChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "maptypeid_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseMove(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mousemove", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseOut(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mouseout", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseOver(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mouseover", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerProjectionChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "projection_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerResize(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "resize", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerRightClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "rightclick", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerTilesLoaded(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "tilesloaded", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerTiltChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "tilt_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerZoomChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "zoom_changed", _varargs);
  }-*/;

}

