/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;

/**
 * A rectangular image overlay on the map.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class GroundOverlay extends MVCObject {

  /**
   * This event is fired when the DOM click event is fired on the
   * <code>GroundOverlay</code>
   * 
   * .
   */
  public interface ClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the DOM dblclick event is fired on the
   * <code>GroundOverlay</code>
   * 
   * .
   */
  public interface DblClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * Creates a ground overlay from the provided image URL and its
   * <code>LatLngBounds</code>
   * 
   * . The image is scaled to fit the current bounds, and projected using
   * the current map projection.
   */ 
  public static native GroundOverlay create(String url, LatLngBounds bounds, GroundOverlayOptions opts)/*-{
    var _opts;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _opts = opts;
    } else {
      _opts = {};
      for(k in opts) {
        if(k != "__gwt_ObjectId") {
          _opts[k] = opts[k];
        }
      }
    } 
    return new $wnd.google.maps.GroundOverlay(url, bounds, _opts);
  }-*/;

  /**
   * Creates a ground overlay from the provided image URL and its
   * <code>LatLngBounds</code>
   * 
   * . The image is scaled to fit the current bounds, and projected using
   * the current map projection.
   */ 
  public static native GroundOverlay create(String url, LatLngBounds bounds)/*-{
    return new $wnd.google.maps.GroundOverlay(url, bounds);
  }-*/;


  /**
   * Protected constructor avoids default public constructor.
   */
  protected GroundOverlay() {
    /* Java constructor is protected, */
  }

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addClickListener(ClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GroundOverlay.ClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "click", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addClickListenerOnce(ClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GroundOverlay.ClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "click", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addDblClickListener(DblClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GroundOverlay.DblClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "dblclick", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addDblClickListenerOnce(DblClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.GroundOverlay.DblClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "dblclick", _handler);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "click");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearDblClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "dblclick");
  }-*/;

  /**
   * Removes all listeners for all events for the given instance.
   */ 
  public final native void clearInstanceListeners()/*-{
    $wnd.google.maps.event.clearInstanceListeners(this);
  }-*/;

  /**
   * Gets the 
   * <code>LatLngBounds</code>
   * 
   * of this overlay.
   */ 
  public final native LatLngBounds getBounds()/*-{
    return this.getBounds();

  }-*/;

  /**
   * Returns the map on which this ground overlay is displayed.
   */ 
  public final native GoogleMap getMap()/*-{
    return this.getMap();

  }-*/;

  /**
   * Returns the opacity of this ground overlay.
   */ 
  public final native double getOpacity()/*-{
    return this.getOpacity();

  }-*/;

  /**
   * Gets the url of the projected image.
   */ 
  public final native String getUrl()/*-{
    return this.getUrl();

  }-*/;

  /**
   * Renders the ground overlay on the specified map. If map is set to
   * null, the overlay is removed.
   */ 
  public final native void setMap(GoogleMap map)/*-{
    this.setMap(map);

  }-*/;

  /**
   * Sets the opacity of this ground overlay.
   */ 
  public final native void setOpacity(double opacity)/*-{
    this.setOpacity(opacity);

  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "click", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerDblClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "dblclick", _varargs);
  }-*/;

}

