/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;

/**
 * Data for a single KML feature in JSON format, returned when a KML
 * feature is clicked. The data contained in this object mirrors that
 * associated with the feature in the KML or GeoRSS markup in which it
 * is declared.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class KmlFeatureData extends JavaScriptObject {


  /**
   * Protected constructor avoids default public constructor.
   */
  protected KmlFeatureData() {
    /* Java constructor is protected, */
  }

  /**
   * The feature's 
   * <code>&lt;atom:author&gt;</code>
   * 
   * , extracted from the layer markup (if specified).
   */ 
  public final native KmlAuthor getAuthor()/*-{
    return this.author;

  }-*/;

  /**
   * The feature's 
   * <code>&lt;description&gt;</code>
   * 
   * , extracted from the layer markup.
   */ 
  public final native String getDescription()/*-{
    return this.description;

  }-*/;

  /**
   * The feature's 
   * <code>&lt;id&gt;</code>
   * 
   * , extracted from the layer markup. If no 
   * <code>&lt;id&gt;</code>
   * 
   * has been specified, a unique ID will be generated for this feature.
   */ 
  public final native String getId()/*-{
    return this.id;

  }-*/;

  /**
   * The feature's balloon styled text, if set.
   */ 
  public final native String getInfoWindowHtml()/*-{
    return this.infoWindowHtml;

  }-*/;

  /**
   * The feature's 
   * <code>&lt;name&gt;</code>
   * 
   * , extracted from the layer markup.
   */ 
  public final native String getName()/*-{
    return this.name;

  }-*/;

  /**
   * The feature's 
   * <code>&lt;Snippet&gt;</code>
   * 
   * , extracted from the layer markup.
   */ 
  public final native String getSnippet()/*-{
    return this.snippet;

  }-*/;

  /**
   * The feature's 
   * <code>&lt;atom:author&gt;</code>
   * 
   * , extracted from the layer markup (if specified).
   */ 
  public final native void setAuthor(KmlAuthor author)/*-{
    this.author = author;
  }-*/;

  /**
   * The feature's 
   * <code>&lt;description&gt;</code>
   * 
   * , extracted from the layer markup.
   */ 
  public final native void setDescription(String description)/*-{
    this.description = description;
  }-*/;

  /**
   * The feature's 
   * <code>&lt;id&gt;</code>
   * 
   * , extracted from the layer markup. If no 
   * <code>&lt;id&gt;</code>
   * 
   * has been specified, a unique ID will be generated for this feature.
   */ 
  public final native void setId(String id)/*-{
    this.id = id;
  }-*/;

  /**
   * The feature's balloon styled text, if set.
   */ 
  public final native void setInfoWindowHtml(String infoWindowHtml)/*-{
    this.infoWindowHtml = infoWindowHtml;
  }-*/;

  /**
   * The feature's 
   * <code>&lt;name&gt;</code>
   * 
   * , extracted from the layer markup.
   */ 
  public final native void setName(String name)/*-{
    this.name = name;
  }-*/;

  /**
   * The feature's 
   * <code>&lt;Snippet&gt;</code>
   * 
   * , extracted from the layer markup.
   */ 
  public final native void setSnippet(String snippet)/*-{
    this.snippet = snippet;
  }-*/;

}

