/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;

/**
 * A 
 * <code>KmlLayer</code>
 * 
 * adds geographic markup to the map from a KML, KMZ or GeoRSS file that
 * is hosted on a publicly accessible web server. A
 * <code>KmlFeatureData</code>
 * 
 * object is provided for each feature when clicked.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class KmlLayer extends MVCObject {

  /**
   * This event is fired when a feature in the layer is clicked.
   */
  public interface ClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(KmlMouseEvent kmlClickEvent);
  }

  /**
   * This event is fired when the KML layers default viewport has changed.
   */
  public interface DefaultviewportChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the KML layer has finished loading. At this
   * point it is safe to read the status property to determine if the
   * layer loaded successfully.
   */
  public interface StatusChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * Creates a 
   * <code>KmlLayer</code>
   * 
   * which renders the contents of the specified KML/KMZ file (<a
   * href="https://developers.google.com/kml/documentation/kmlreference">https://developers.google.com/km
   * l/documentation/kmlreference</a>) or GeoRSS file (<a
   * href="http://www.georss.org">http://www.georss.org</a>).
   */ 
  public static native KmlLayer create(String url, KmlLayerOptions opts)/*-{
    var _opts;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _opts = opts;
    } else {
      _opts = {};
      for(k in opts) {
        if(k != "__gwt_ObjectId") {
          _opts[k] = opts[k];
        }
      }
    } 
    return new $wnd.google.maps.KmlLayer(url, _opts);
  }-*/;

  /**
   * Creates a 
   * <code>KmlLayer</code>
   * 
   * which renders the contents of the specified KML/KMZ file (<a
   * href="https://developers.google.com/kml/documentation/kmlreference">https://developers.google.com/km
   * l/documentation/kmlreference</a>) or GeoRSS file (<a
   * href="http://www.georss.org">http://www.georss.org</a>).
   */ 
  public static native KmlLayer create(String url)/*-{
    return new $wnd.google.maps.KmlLayer(url);
  }-*/;


  /**
   * Protected constructor avoids default public constructor.
   */
  protected KmlLayer() {
    /* Java constructor is protected, */
  }

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addClickListener(ClickHandler handler)/*-{
    var _handler = $entry(function(kmlClickEvent) {
      handler.@com.google.maps.gwt.client.KmlLayer.ClickHandler::handle(Lcom/google/maps/gwt/client/KmlMouseEvent;)(kmlClickEvent);

    }); 
    $wnd.google.maps.event.addListener(this, "click", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addClickListenerOnce(ClickHandler handler)/*-{
    var _handler = $entry(function(kmlClickEvent) {
      handler.@com.google.maps.gwt.client.KmlLayer.ClickHandler::handle(Lcom/google/maps/gwt/client/KmlMouseEvent;)(kmlClickEvent);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "click", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addDefaultviewportChangedListener(DefaultviewportChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.KmlLayer.DefaultviewportChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "defaultviewport_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addDefaultviewportChangedListenerOnce(DefaultviewportChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.KmlLayer.DefaultviewportChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "defaultviewport_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addStatusChangedListener(StatusChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.KmlLayer.StatusChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "status_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addStatusChangedListenerOnce(StatusChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.KmlLayer.StatusChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "status_changed", _handler);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "click");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearDefaultviewportChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "defaultviewport_changed");
  }-*/;

  /**
   * Removes all listeners for all events for the given instance.
   */ 
  public final native void clearInstanceListeners()/*-{
    $wnd.google.maps.event.clearInstanceListeners(this);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearStatusChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "status_changed");
  }-*/;

  /**
   * Get the default viewport for the layer being displayed.
   */ 
  public final native LatLngBounds getDefaultViewport()/*-{
    return this.getDefaultViewport();

  }-*/;

  /**
   * Get the map on which the KML Layer is being rendered.
   */ 
  public final native GoogleMap getMap()/*-{
    return this.getMap();

  }-*/;

  /**
   * Get the metadata associated with this layer, as specified in the layer markup.
   */ 
  public final native KmlLayerMetadata getMetadata()/*-{
    return this.getMetadata();

  }-*/;

  /**
   * Get the status of the layer, set once the requested document has loaded.
   */ 
  public final native KmlLayerStatus getStatus()/*-{
    var _retval = this.getStatus();
    var retval = (_retval == undefined) ?
        null : @com.google.maps.gwt.client.KmlLayerStatus::fromValue(Ljava/lang/String;)(_retval);
    return retval;
  }-*/;

  /**
   * Get the URL of the geographic markup which is being displayed.
   */ 
  public final native String getUrl()/*-{
    return this.getUrl();

  }-*/;

  /**
   * Renders the KML Layer on the specified map. If map is set to null,
   * the layer is removed.
   */ 
  public final native void setMap(GoogleMap map)/*-{
    this.setMap(map);

  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "click", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerDefaultviewportChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "defaultviewport_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerStatusChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "status_changed", _varargs);
  }-*/;

}

