/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * The status returned by 
 * <code>KmlLayer</code>
 * 
 * on the completion of loading a document.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class KmlLayerStatus extends JavaScriptObject {

  /**
   * The document could not be found. Most likely it is an invalid URL, or
   * the document is not publicly available.
   */ 
  public static final KmlLayerStatus DOCUMENT_NOT_FOUND = getDocumentNotFound();

  /**
   * The document exceeds the file size limits of KmlLayer.
   */ 
  public static final KmlLayerStatus DOCUMENT_TOO_LARGE = getDocumentTooLarge();

  /**
   * The document could not be fetched.
   */ 
  public static final KmlLayerStatus FETCH_ERROR = getFetchError();

  /**
   * The document is not a valid KML, KMZ or GeoRSS document.
   */ 
  public static final KmlLayerStatus INVALID_DOCUMENT = getInvalidDocument();

  /**
   * The 
   * <code>KmlLayer</code>
   * 
   * is invalid.
   */ 
  public static final KmlLayerStatus INVALID_REQUEST = getInvalidRequest();

  /**
   * The document exceeds the feature limits of KmlLayer.
   */ 
  public static final KmlLayerStatus LIMITS_EXCEEDED = getLimitsExceeded();

  /**
   * The request was successful.
   */ 
  public static final KmlLayerStatus OK = getOk();

  /**
   * The document could not be loaded within a reasonable amount of time.
   */ 
  public static final KmlLayerStatus TIMED_OUT = getTimedOut();

  /**
   * The document failed to load for an unknown reason.
   */ 
  public static final KmlLayerStatus UNKNOWN = getUnknown();

  /**
   * Internal registry for value types.
   */ 
  private static Map<String,KmlLayerStatus> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final KmlLayerStatus fromValue(String value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native KmlLayerStatus getDocumentNotFound()/*-{
    var instance = { 'value' : $wnd.google.maps.KmlLayerStatus.DOCUMENT_NOT_FOUND };
    @com.google.maps.gwt.client.KmlLayerStatus::register(Lcom/google/maps/gwt/client/KmlLayerStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native KmlLayerStatus getDocumentTooLarge()/*-{
    var instance = { 'value' : $wnd.google.maps.KmlLayerStatus.DOCUMENT_TOO_LARGE };
    @com.google.maps.gwt.client.KmlLayerStatus::register(Lcom/google/maps/gwt/client/KmlLayerStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native KmlLayerStatus getFetchError()/*-{
    var instance = { 'value' : $wnd.google.maps.KmlLayerStatus.FETCH_ERROR };
    @com.google.maps.gwt.client.KmlLayerStatus::register(Lcom/google/maps/gwt/client/KmlLayerStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native KmlLayerStatus getInvalidDocument()/*-{
    var instance = { 'value' : $wnd.google.maps.KmlLayerStatus.INVALID_DOCUMENT };
    @com.google.maps.gwt.client.KmlLayerStatus::register(Lcom/google/maps/gwt/client/KmlLayerStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native KmlLayerStatus getInvalidRequest()/*-{
    var instance = { 'value' : $wnd.google.maps.KmlLayerStatus.INVALID_REQUEST };
    @com.google.maps.gwt.client.KmlLayerStatus::register(Lcom/google/maps/gwt/client/KmlLayerStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native KmlLayerStatus getLimitsExceeded()/*-{
    var instance = { 'value' : $wnd.google.maps.KmlLayerStatus.LIMITS_EXCEEDED };
    @com.google.maps.gwt.client.KmlLayerStatus::register(Lcom/google/maps/gwt/client/KmlLayerStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native KmlLayerStatus getOk()/*-{
    var instance = { 'value' : $wnd.google.maps.KmlLayerStatus.OK };
    @com.google.maps.gwt.client.KmlLayerStatus::register(Lcom/google/maps/gwt/client/KmlLayerStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native KmlLayerStatus getTimedOut()/*-{
    var instance = { 'value' : $wnd.google.maps.KmlLayerStatus.TIMED_OUT };
    @com.google.maps.gwt.client.KmlLayerStatus::register(Lcom/google/maps/gwt/client/KmlLayerStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native KmlLayerStatus getUnknown()/*-{
    var instance = { 'value' : $wnd.google.maps.KmlLayerStatus.UNKNOWN };
    @com.google.maps.gwt.client.KmlLayerStatus::register(Lcom/google/maps/gwt/client/KmlLayerStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(KmlLayerStatus value){
    if (registry == null) {
      registry = new HashMap<String, KmlLayerStatus>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected KmlLayerStatus() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native String getValue()/*-{
    return this.value;
  }-*/;

}

