/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;

/**
 * <code><a href="#LatLng">LatLng</a></code>
 * 
 * is a point in geographical coordinates, latitude and longitude.</p>
 * <p>Notice that although usual map projections associate longitude
 * with the x-coordinate of the map, and latitude with the y-coordinate,
 * the latitude coordinate is always written <em>first</em>, followed by
 * the longitude.</p> <p>Notice also that you cannot modify the
 * coordinates of a
 * <code><a href="#LatLng">LatLng</a></code>
 * 
 * . If you want to compute another point, you have to create a new one.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class LatLng extends JavaScriptObject {

  /**
   * Notice the ordering of latitude and longitude. If the noWrap flag is
   * true, then the numbers will be used as passed, otherwise latitude
   * will be clamped to lie between -90 degrees and +90 degrees, and
   * longitude will be wrapped to lie between -180 degrees and +180
   * degrees.
   */ 
  public static native LatLng create(double lat, double lng, boolean noWrap)/*-{
    return new $wnd.google.maps.LatLng(lat, lng, noWrap);
  }-*/;

  /**
   * Notice the ordering of latitude and longitude. If the noWrap flag is
   * true, then the numbers will be used as passed, otherwise latitude
   * will be clamped to lie between -90 degrees and +90 degrees, and
   * longitude will be wrapped to lie between -180 degrees and +180
   * degrees.
   */ 
  public static native LatLng create(double lat, double lng)/*-{
    return new $wnd.google.maps.LatLng(lat, lng);
  }-*/;


  /**
   * Protected constructor avoids default public constructor.
   */
  protected LatLng() {
    /* Java constructor is protected, */
  }

  /**
   * Comparison function.
   */ 
  public final native boolean equals(LatLng other)/*-{
    return this.equals(other);

  }-*/;

  /**
   * Returns the latitude in degrees.
   */ 
  public final native double lat()/*-{
    return this.lat();

  }-*/;

  /**
   * Returns the longitude in degrees.
   */ 
  public final native double lng()/*-{
    return this.lng();

  }-*/;

  /**
   * Returns a string of the form "lat,lng" for this LatLng. We round the
   * lat/lng values to 6 decimal places by default.
   */ 
  public final native String toUrlValue(double precision)/*-{
    return this.toUrlValue(precision);

  }-*/;

  /**
   * Returns a string of the form "lat,lng" for this LatLng. We round the
   * lat/lng values to 6 decimal places by default.
   */ 
  public final native String toUrlValue()/*-{
    return this.toUrlValue();

  }-*/;

}

