/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArray;

/**
 * MVCArray adds type parameterization to the generated MVCArray wrapper
 * included in the Maps codebase.
 *
 * @author dcarlson@google.com (David Carlson)
 */
public class MVCArray<A extends JavaScriptObject> extends JavaScriptObject {

  /**
   * Callback type for handling asynchronous responses from forEach.
   */
  public interface ForEachCallback<T extends JavaScriptObject> {

    /**
     * Called by the callback handler.
     */
    void handle(T a);
  }

  /**
   * A mutable MVC Array.
   */
  public static final native <T extends JavaScriptObject> MVCArray<T> create(
      JsArray<T> array) /*-{
    return new $wnd.google.maps.MVCArray(array);
  }-*/;

  /**
   * A mutable MVC Array.
   */
  public static final native <T extends JavaScriptObject> MVCArray<T> create()/*-{
    return new $wnd.google.maps.MVCArray();
  }-*/;

  /**
   * Protected constructor for internal use only.
   */
  protected MVCArray() {
    /* Java constructor is protected, */
  }

  /**
   * Removes all elements from the array.
   */
  public final native void clear()/*-{
    this.clear();
  }-*/;

  /**
   * Iterate over each element, calling the provided callback. The callback is
   * called for each element like: callback(element, index).
   */
  public final native void forEach(ForEachCallback<A> callback)/*-{
    var _callback = $entry(function(a) {
      callback.@com.google.maps.gwt.client.MVCArray.ForEachCallback::handle(Lcom/google/gwt/core/client/JavaScriptObject;)(a);
    });
    this.forEach(_callback);
  }-*/;

  /**
   * Returns a reference to the underlying Array. Warning: if the Array is
   * mutated, no events will be fired by this object.
   */
  public final native JsArray<A> getArray()/*-{
    return this.getArray();
  }-*/;

  /**
   * Get an element at the specified index.
   */
  public final native A getAt(double i)/*-{
    return this.getAt(i);
  }-*/;

  /**
   * Returns the number of elements in this array.
   */
  public final native double getLength()/*-{
    return this.getLength();
  }-*/;

  /**
   * Inserts an element at the specified index.
   */
  public final native void insertAt(double i, A elem)/*-{
    this.insertAt(i, elem);
  }-*/;

  /**
   * Removes the last element of the array and returns that element.
   */
  public final native A pop()/*-{
    return this.pop();
  }-*/;

  /**
   * Adds one element to the end of the array and returns the new length of the
   * array.
   */
  public final native double push(A elem)/*-{
    return this.push(elem);
  }-*/;

  /**
   * Removes an element from the specified index.
   */
  public final native A removeAt(double i)/*-{
    return this.removeAt(i);
  }-*/;

  /**
   * Sets an element at the specified index.
   */
  public final native void setAt(double i, A elem)/*-{
    this.setAt(i, elem);
  }-*/;

}
