/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;

/**
 * 
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class MapFeaturesTracker extends JavaScriptObject {

  /**
   * This event is fired whenever Street View coverage within the map changes.
   */
  public interface StreetviewChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired whenever traffic coverage within the map changes.
   */
  public interface TrafficChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected MapFeaturesTracker() {
    /* Java constructor is protected, */
  }

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addStreetviewChangedListener(StreetviewChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.MapFeaturesTracker.StreetviewChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "streetview_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addStreetviewChangedListenerOnce(StreetviewChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.MapFeaturesTracker.StreetviewChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "streetview_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addTrafficChangedListener(TrafficChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.MapFeaturesTracker.TrafficChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "traffic_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addTrafficChangedListenerOnce(TrafficChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.MapFeaturesTracker.TrafficChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "traffic_changed", _handler);
  }-*/;

  /**
   * Removes all listeners for all events for the given instance.
   */ 
  public final native void clearInstanceListeners()/*-{
    $wnd.google.maps.event.clearInstanceListeners(this);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearStreetviewChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "streetview_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearTrafficChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "traffic_changed");
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerStreetviewChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "streetview_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerTrafficChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "traffic_changed", _varargs);
  }-*/;

}

