/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArray;

/**
 * 
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class MapOptions extends JavaScriptObject {

  public static final MapOptions create(){
    return JavaScriptObject.createObject().cast();
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected MapOptions() {
    /* Java constructor is protected, */
  }

  /**
   * Color used for the background of the Map div.  This color will be
   * visible when tiles have not yet loaded as the user pans.  This option
   * can only be set when the map is initialized.
   */ 
  public final native void setBackgroundColor(String backgroundColor)/*-{
    this.backgroundColor = backgroundColor;
  }-*/;

  /**
   * The initial Map center. Required.
   */ 
  public final native void setCenter(LatLng center)/*-{
    this.center = center;
  }-*/;

  /**
   * Enables/disables all default UI. May be overridden individually.
   */ 
  public final native void setDisableDefaultUi(boolean disableDefaultUI)/*-{
    this.disableDefaultUI = disableDefaultUI;
  }-*/;

  /**
   * Enables/disables zoom and center on double click. Enabled by default.
   */ 
  public final native void setDisableDoubleClickZoom(boolean disableDoubleClickZoom)/*-{
    this.disableDoubleClickZoom = disableDoubleClickZoom;
  }-*/;

  /**
   * If false, prevents the map from being dragged.  Dragging is enabled by default.
   */ 
  public final native void setDraggable(boolean draggable)/*-{
    this.draggable = draggable;
  }-*/;

  /**
   * The name or url of the cursor to display on a draggable object.
   */ 
  public final native void setDraggableCursor(String draggableCursor)/*-{
    this.draggableCursor = draggableCursor;
  }-*/;

  /**
   * The name or url of the cursor to display when an object is dragging.
   */ 
  public final native void setDraggingCursor(String draggingCursor)/*-{
    this.draggingCursor = draggingCursor;
  }-*/;

  /**
   * The heading for aerial imagery in degrees measured clockwise from
   * cardinal direction North. Headings are snapped to the nearest
   * available angle for which imagery is available.
   */ 
  public final native void setHeading(double heading)/*-{
    this.heading = heading;
  }-*/;

  /**
   * If false, prevents the map from being controlled by the keyboard.
   * Keyboard shortcuts are enabled by default.
   */ 
  public final native void setKeyboardShortcuts(boolean keyboardShortcuts)/*-{
    this.keyboardShortcuts = keyboardShortcuts;
  }-*/;

  /**
   * True if Map Maker tiles should be used instead of regular tiles.
   */ 
  public final native void setMapMaker(boolean mapMaker)/*-{
    this.mapMaker = mapMaker;
  }-*/;

  /**
   * The initial enabled/disabled state of the Map type control.
   */ 
  public final native void setMapTypeControl(boolean mapTypeControl)/*-{
    this.mapTypeControl = mapTypeControl;
  }-*/;

  /**
   * The initial display options for the Map type control.
   */ 
  public final native void setMapTypeControlOptions(MapTypeControlOptions mapTypeControlOptions)/*-{
    var _mapTypeControlOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _mapTypeControlOptions = mapTypeControlOptions;
    } else {
      _mapTypeControlOptions = {};
      for(k in mapTypeControlOptions) {
        if(k != "__gwt_ObjectId") {
          _mapTypeControlOptions[k] = mapTypeControlOptions[k];
        }
      }
    } 
    this.mapTypeControlOptions = _mapTypeControlOptions;
  }-*/;

  /**
   * The initial Map mapTypeId. Required.
   */ 
  public final native void setMapTypeId(MapTypeId mapTypeId)/*-{
    var _mapTypeId = mapTypeId == undefined ? null : mapTypeId.value; 
    this.mapTypeId = _mapTypeId;
  }-*/;

  /**
   * The maximum zoom level which will be displayed on the map. If
   * omitted, or set to null, the maximum zoom from the current map type
   * is used instead.
   */ 
  public final native void setMaxZoom(double maxZoom)/*-{
    this.maxZoom = maxZoom;
  }-*/;

  /**
   * The minimum zoom level which will be displayed on the map. If
   * omitted, or set to null, the minimum zoom from the current map type
   * is used instead.
   */ 
  public final native void setMinZoom(double minZoom)/*-{
    this.minZoom = minZoom;
  }-*/;

  /**
   * If true, do not clear the contents of the Map div.
   */ 
  public final native void setNoClear(boolean noClear)/*-{
    this.noClear = noClear;
  }-*/;

  /**
   * The enabled/disabled state of the Overview Map control.
   */ 
  public final native void setOverviewMapControl(boolean overviewMapControl)/*-{
    this.overviewMapControl = overviewMapControl;
  }-*/;

  /**
   * The display options for the Overview Map control.
   */ 
  public final native void setOverviewMapControlOptions(OverviewMapControlOptions overviewMapControlOptions)/*-{
    var _overviewMapControlOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _overviewMapControlOptions = overviewMapControlOptions;
    } else {
      _overviewMapControlOptions = {};
      for(k in overviewMapControlOptions) {
        if(k != "__gwt_ObjectId") {
          _overviewMapControlOptions[k] = overviewMapControlOptions[k];
        }
      }
    } 
    this.overviewMapControlOptions = _overviewMapControlOptions;
  }-*/;

  /**
   * The enabled/disabled state of the Pan control.
   */ 
  public final native void setPanControl(boolean panControl)/*-{
    this.panControl = panControl;
  }-*/;

  /**
   * The display options for the Pan control.
   */ 
  public final native void setPanControlOptions(PanControlOptions panControlOptions)/*-{
    var _panControlOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _panControlOptions = panControlOptions;
    } else {
      _panControlOptions = {};
      for(k in panControlOptions) {
        if(k != "__gwt_ObjectId") {
          _panControlOptions[k] = panControlOptions[k];
        }
      }
    } 
    this.panControlOptions = _panControlOptions;
  }-*/;

  /**
   * The enabled/disabled state of the Rotate control.
   */ 
  public final native void setRotateControl(boolean rotateControl)/*-{
    this.rotateControl = rotateControl;
  }-*/;

  /**
   * The display options for the Rotate control.
   */ 
  public final native void setRotateControlOptions(RotateControlOptions rotateControlOptions)/*-{
    var _rotateControlOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _rotateControlOptions = rotateControlOptions;
    } else {
      _rotateControlOptions = {};
      for(k in rotateControlOptions) {
        if(k != "__gwt_ObjectId") {
          _rotateControlOptions[k] = rotateControlOptions[k];
        }
      }
    } 
    this.rotateControlOptions = _rotateControlOptions;
  }-*/;

  /**
   * The initial enabled/disabled state of the Scale control.
   */ 
  public final native void setScaleControl(boolean scaleControl)/*-{
    this.scaleControl = scaleControl;
  }-*/;

  /**
   * The initial display options for the Scale control.
   */ 
  public final native void setScaleControlOptions(ScaleControlOptions scaleControlOptions)/*-{
    var _scaleControlOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _scaleControlOptions = scaleControlOptions;
    } else {
      _scaleControlOptions = {};
      for(k in scaleControlOptions) {
        if(k != "__gwt_ObjectId") {
          _scaleControlOptions[k] = scaleControlOptions[k];
        }
      }
    } 
    this.scaleControlOptions = _scaleControlOptions;
  }-*/;

  /**
   * If false, disables scrollwheel zooming on the map.  The scrollwheel
   * is enabled by default.
   */ 
  public final native void setScrollwheel(boolean scrollwheel)/*-{
    this.scrollwheel = scrollwheel;
  }-*/;

  /**
   * A 
   * <code>StreetViewPanorama</code>
   * 
   * to display when the Street View pegman is dropped on the map.  If no
   * panorama is specified, a default
   * <code>StreetViewPanorama</code>
   * 
   * will be displayed in the map's
   * <code>div</code>
   * 
   * when the pegman is dropped.
   */ 
  public final native void setStreetView(StreetViewPanorama streetView)/*-{
    this.streetView = streetView;
  }-*/;

  /**
   * The initial enabled/disabled state of the Street View Pegman control.
   * This control is part of the default UI, and should be set to
   * <code>false</code>
   * 
   * when displaying a map type on which the Street View road overlay
   * should not appear (e.g. a non-Earth map type).
   */ 
  public final native void setStreetViewControl(boolean streetViewControl)/*-{
    this.streetViewControl = streetViewControl;
  }-*/;

  /**
   * The initial display options for the Street View Pegman control.
   */ 
  public final native void setStreetViewControlOptions(StreetViewControlOptions streetViewControlOptions)/*-{
    var _streetViewControlOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _streetViewControlOptions = streetViewControlOptions;
    } else {
      _streetViewControlOptions = {};
      for(k in streetViewControlOptions) {
        if(k != "__gwt_ObjectId") {
          _streetViewControlOptions[k] = streetViewControlOptions[k];
        }
      }
    } 
    this.streetViewControlOptions = _streetViewControlOptions;
  }-*/;

  /**
   * Styles to apply to each of the default map types.  Note that styles
   * will apply only to the labels and geometry in Satellite/Hybrid and
   * Terrain modes.
   */ 
  public final native void setStyles(JsArray<MapTypeStyle> styles)/*-{
    this.styles = styles;
  }-*/;

  /**
   * The angle of incidence of the map as measured in degrees from the
   * viewport plane to the map plane.  The only currently supported values
   * are
   * <code>0</code>
   * 
   * , indicating no angle of incidence (no tilt), and
   * <code>45</code>
   * 
   * , indicating a tilt of 45deg;.  45deg; imagery is only available for 
   * <code>SATELLITE</code>
   * 
   *  and 
   * <code>HYBRID</code>
   * 
   * map types, within some locations, and at some zoom levels.
   */ 
  public final native void setTilt(double tilt)/*-{
    this.tilt = tilt;
  }-*/;

  /**
   * The initial Map zoom level. Required.
   */ 
  public final native void setZoom(double zoom)/*-{
    this.zoom = zoom;
  }-*/;

  /**
   * The enabled/disabled state of the Zoom control.
   */ 
  public final native void setZoomControl(boolean zoomControl)/*-{
    this.zoomControl = zoomControl;
  }-*/;

  /**
   * The display options for the Zoom control.
   */ 
  public final native void setZoomControlOptions(ZoomControlOptions zoomControlOptions)/*-{
    var _zoomControlOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _zoomControlOptions = zoomControlOptions;
    } else {
      _zoomControlOptions = {};
      for(k in zoomControlOptions) {
        if(k != "__gwt_ObjectId") {
          _zoomControlOptions[k] = zoomControlOptions[k];
        }
      }
    } 
    this.zoomControlOptions = _zoomControlOptions;
  }-*/;

}

