/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.dom.client.Node;

/**
 * This object contains the DOM elements in which overlays are rendered.
 * They are listed below with 'Pane 0' at the bottom and 'Pane 6' at the
 * top.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class MapPanes extends JavaScriptObject {


  /**
   * Protected constructor avoids default public constructor.
   */
  protected MapPanes() {
    /* Java constructor is protected, */
  }

  /**
   * This pane contains the info window. It is above all map overlays. (Pane 6).
   */ 
  public final native Node getFloatPane()/*-{
    return this.floatPane;

  }-*/;

  /**
   * This pane contains the info window shadow. It is above the
   * overlayImage, so that markers can be in the shadow of the info
   * window. (Pane 4).
   */ 
  public final native Node getFloatShadow()/*-{
    return this.floatShadow;

  }-*/;

  /**
   * This pane is the lowest pane and is above the tiles. It may not
   * receive DOM events. (Pane 0).
   */ 
  public final native Node getMapPane()/*-{
    return this.mapPane;

  }-*/;

  /**
   * This pane contains the marker foreground images. (Pane 3).
   */ 
  public final native Node getOverlayImage()/*-{
    return this.overlayImage;

  }-*/;

  /**
   * This pane contains polylines, polygons, ground overlays and tile
   * layer overlays. It may not receive DOM events. (Pane 1).
   */ 
  public final native Node getOverlayLayer()/*-{
    return this.overlayLayer;

  }-*/;

  /**
   * This pane contains elements that receive DOM mouse events, such as
   * the transparent targets for markers. It is above the floatShadow, so
   * that markers in the shadow of the info window can be clickable. (Pane
   * 5).
   */ 
  public final native Node getOverlayMouseTarget()/*-{
    return this.overlayMouseTarget;

  }-*/;

  /**
   * This pane contains the marker shadows. It may not receive DOM events. (Pane 2).
   */ 
  public final native Node getOverlayShadow()/*-{
    return this.overlayShadow;

  }-*/;

  /**
   * This pane contains the info window. It is above all map overlays. (Pane 6).
   */ 
  public final native void setFloatPane(Node floatPane)/*-{
    this.floatPane = floatPane;
  }-*/;

  /**
   * This pane contains the info window shadow. It is above the
   * overlayImage, so that markers can be in the shadow of the info
   * window. (Pane 4).
   */ 
  public final native void setFloatShadow(Node floatShadow)/*-{
    this.floatShadow = floatShadow;
  }-*/;

  /**
   * This pane is the lowest pane and is above the tiles. It may not
   * receive DOM events. (Pane 0).
   */ 
  public final native void setMapPane(Node mapPane)/*-{
    this.mapPane = mapPane;
  }-*/;

  /**
   * This pane contains the marker foreground images. (Pane 3).
   */ 
  public final native void setOverlayImage(Node overlayImage)/*-{
    this.overlayImage = overlayImage;
  }-*/;

  /**
   * This pane contains polylines, polygons, ground overlays and tile
   * layer overlays. It may not receive DOM events. (Pane 1).
   */ 
  public final native void setOverlayLayer(Node overlayLayer)/*-{
    this.overlayLayer = overlayLayer;
  }-*/;

  /**
   * This pane contains elements that receive DOM mouse events, such as
   * the transparent targets for markers. It is above the floatShadow, so
   * that markers in the shadow of the info window can be clickable. (Pane
   * 5).
   */ 
  public final native void setOverlayMouseTarget(Node overlayMouseTarget)/*-{
    this.overlayMouseTarget = overlayMouseTarget;
  }-*/;

  /**
   * This pane contains the marker shadows. It may not receive DOM events. (Pane 2).
   */ 
  public final native void setOverlayShadow(Node overlayShadow)/*-{
    this.overlayShadow = overlayShadow;
  }-*/;

}

