/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.dom.client.Document;
import com.google.gwt.dom.client.Node;

/**
 * This interface defines the map type, and is typically used for custom
 * map types.  Immutable.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class MapType extends JavaScriptObject {


  /**
   * Protected constructor avoids default public constructor.
   */
  protected MapType() {
    /* Java constructor is protected, */
  }

  /**
   * Alt text to display when this MapType's button is hovered over in the
   * MapTypeControl. Optional.
   */ 
  public final native String getAlt()/*-{
    return this.alt;

  }-*/;

  /**
   * The maximum zoom level for the map when displaying this MapType.
   * Required for base MapTypes, ignored for overlay MapTypes.
   */ 
  public final native double getMaxZoom()/*-{
    return this.maxZoom;

  }-*/;

  /**
   * The minimum zoom level for the map when displaying this MapType.
   * Optional; defaults to 0.
   */ 
  public final native double getMinZoom()/*-{
    return this.minZoom;

  }-*/;

  /**
   * Name to display in the MapTypeControl. Optional.
   */ 
  public final native String getName()/*-{
    return this.name;

  }-*/;

  /**
   * The Projection used to render this MapType. Optional; defaults to Mercator.
   */ 
  public final native Projection getProjection()/*-{
    return this.projection;

  }-*/;

  /**
   * Radius of the planet for the map, in meters. Optional; defaults to
   * Earth's equatorial radius of 6378137 meters.
   */ 
  public final native double getRadius()/*-{
    return this.radius;

  }-*/;

  /**
   * Returns a tile for the given tile coordinate (x, y) and zoom level.
   * This tile will be appended to the given ownerDocument.  Not available
   * for base map types.
   */ 
  public final native Node getTile(Point tileCoord, double zoom, Document ownerDocument)/*-{
    return this.getTile(tileCoord, zoom, ownerDocument);

  }-*/;

  /**
   * The dimensions of each tile. Required.
   */ 
  public final native Size getTileSize()/*-{
    return this.tileSize;

  }-*/;

  /**
   * Releases the given tile, performing any necessary cleanup. The
   * provided tile will have already been removed from the document.
   * Optional.
   */ 
  public final native void releaseTile(Node tile)/*-{
    this.releaseTile(tile);

  }-*/;

  /**
   * Alt text to display when this MapType's button is hovered over in the
   * MapTypeControl. Optional.
   */ 
  public final native void setAlt(String alt)/*-{
    this.alt = alt;
  }-*/;

  /**
   * The maximum zoom level for the map when displaying this MapType.
   * Required for base MapTypes, ignored for overlay MapTypes.
   */ 
  public final native void setMaxZoom(double maxZoom)/*-{
    this.maxZoom = maxZoom;
  }-*/;

  /**
   * The minimum zoom level for the map when displaying this MapType.
   * Optional; defaults to 0.
   */ 
  public final native void setMinZoom(double minZoom)/*-{
    this.minZoom = minZoom;
  }-*/;

  /**
   * Name to display in the MapTypeControl. Optional.
   */ 
  public final native void setName(String name)/*-{
    this.name = name;
  }-*/;

  /**
   * The Projection used to render this MapType. Optional; defaults to Mercator.
   */ 
  public final native void setProjection(Projection projection)/*-{
    this.projection = projection;
  }-*/;

  /**
   * Radius of the planet for the map, in meters. Optional; defaults to
   * Earth's equatorial radius of 6378137 meters.
   */ 
  public final native void setRadius(double radius)/*-{
    this.radius = radius;
  }-*/;

  /**
   * The dimensions of each tile. Required.
   */ 
  public final native void setTileSize(Size tileSize)/*-{
    this.tileSize = tileSize;
  }-*/;

}

