/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * Identifiers for common MapTypesControls.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class MapTypeControlStyle extends JavaScriptObject {

  /**
   * Uses the default map type control. The control which DEFAULT maps to
   * will vary according to window size and other factors. It may change
   * in future versions of the API.
   */ 
  public static final MapTypeControlStyle DEFAULT = getDefault();

  /**
   * A dropdown menu for the screen realestate conscious.
   */ 
  public static final MapTypeControlStyle DROPDOWN_MENU = getDropdownMenu();

  /**
   * The standard horizontal radio buttons bar.
   */ 
  public static final MapTypeControlStyle HORIZONTAL_BAR = getHorizontalBar();

  /**
   * Internal registry for value types.
   */ 
  private static Map<Double,MapTypeControlStyle> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final MapTypeControlStyle fromValue(double value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native MapTypeControlStyle getDefault()/*-{
    var instance = { 'value' : $wnd.google.maps.MapTypeControlStyle.DEFAULT };
    @com.google.maps.gwt.client.MapTypeControlStyle::register(Lcom/google/maps/gwt/client/MapTypeControlStyle;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native MapTypeControlStyle getDropdownMenu()/*-{
    var instance = { 'value' : $wnd.google.maps.MapTypeControlStyle.DROPDOWN_MENU };
    @com.google.maps.gwt.client.MapTypeControlStyle::register(Lcom/google/maps/gwt/client/MapTypeControlStyle;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native MapTypeControlStyle getHorizontalBar()/*-{
    var instance = { 'value' : $wnd.google.maps.MapTypeControlStyle.HORIZONTAL_BAR };
    @com.google.maps.gwt.client.MapTypeControlStyle::register(Lcom/google/maps/gwt/client/MapTypeControlStyle;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(MapTypeControlStyle value){
    if (registry == null) {
      registry = new HashMap<Double, MapTypeControlStyle>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected MapTypeControlStyle() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native double getValue()/*-{
    return this.value;
  }-*/;

}

