/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * Identifiers for common MapTypes.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class MapTypeId extends JavaScriptObject {

  /**
   * This map type displays a transparent layer of major streets on satellite images.
   */ 
  public static final MapTypeId HYBRID = getHybrid();

  /**
   * This map type displays a normal street map.
   */ 
  public static final MapTypeId ROADMAP = getRoadmap();

  /**
   * This map type displays satellite images.
   */ 
  public static final MapTypeId SATELLITE = getSatellite();

  /**
   * This map type displays maps with physical features such as terrain and vegetation.
   */ 
  public static final MapTypeId TERRAIN = getTerrain();

  /**
   * Internal registry for value types.
   */ 
  private static Map<String,MapTypeId> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final MapTypeId fromValue(String value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native MapTypeId getHybrid()/*-{
    var instance = { 'value' : $wnd.google.maps.MapTypeId.HYBRID };
    @com.google.maps.gwt.client.MapTypeId::register(Lcom/google/maps/gwt/client/MapTypeId;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native MapTypeId getRoadmap()/*-{
    var instance = { 'value' : $wnd.google.maps.MapTypeId.ROADMAP };
    @com.google.maps.gwt.client.MapTypeId::register(Lcom/google/maps/gwt/client/MapTypeId;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native MapTypeId getSatellite()/*-{
    var instance = { 'value' : $wnd.google.maps.MapTypeId.SATELLITE };
    @com.google.maps.gwt.client.MapTypeId::register(Lcom/google/maps/gwt/client/MapTypeId;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native MapTypeId getTerrain()/*-{
    var instance = { 'value' : $wnd.google.maps.MapTypeId.TERRAIN };
    @com.google.maps.gwt.client.MapTypeId::register(Lcom/google/maps/gwt/client/MapTypeId;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(MapTypeId value){
    if (registry == null) {
      registry = new HashMap<String, MapTypeId>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected MapTypeId() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native String getValue()/*-{
    return this.value;
  }-*/;

}

