/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArray;

/**
 * The 
 * <code>MapTypeStyle</code>
 * 
 * is a collection of selectors and stylers that define how the map
 * should be styled.  Selectors specify what map elements should be
 * affected and stylers specify how those elements should be modified.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class MapTypeStyle extends JavaScriptObject {

  public static final MapTypeStyle create(){
    return JavaScriptObject.createObject().cast();
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected MapTypeStyle() {
    /* Java constructor is protected, */
  }

  /**
   * Selects the element type to which a styler should be applied.  An
   * element type distinguishes between the different representations of a
   * feature.  Optional; if
   * <code>elementType</code>
   * 
   * is not specified, the value is assumed to be 
   * <code>'all'</code>
   * 
   * .
   */ 
  public final native void setElementType(MapTypeStyleElementType elementType)/*-{
    var _elementType = elementType == undefined ? null : elementType.value; 
    this.elementType = _elementType;
  }-*/;

  /**
   * Selects the feature, or group of features, to which a styler should
   * be applied.  Optional; if
   * <code>featureType</code>
   * 
   * is not specified, the value is assumed to be 
   * <code>'all'</code>
   * 
   * .
   */ 
  public final native void setFeatureType(MapTypeStyleFeatureType featureType)/*-{
    var _featureType = featureType == undefined ? null : featureType.value; 
    this.featureType = _featureType;
  }-*/;

  /**
   * The style rules to apply to the selectors.  The rules are applied to
   * the map's elements in the order they are listed in this array.
   */ 
  public final native void setStylers(JsArray<MapTypeStyler> stylers)/*-{
    this.stylers = stylers;
  }-*/;

}

