/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import java.util.HashMap;

import com.google.gwt.core.client.JavaScriptObject;

/**
 * This enumeration type overrides behavior of the generated gwt binding. The
 * underlying javascript type does not have real enum values, but instead looks
 * for specific strings. As a result, we create instances rather than just
 * dereferencing them.
 *
 * NOTE: The collection of feature types listed in this file need to be
 * maintained by hand.
 *
 * @author dcarlson@google.com (David Carlson)
 */
public class MapTypeStyleFeatureType extends JavaScriptObject {

  /**
   * Apply the rule to administrative areas.
   */
  public static final MapTypeStyleFeatureType ADMINISTRATIVE =
      create("administrative");

  /**
   * Apply the rule to countries.
   */
  public static final MapTypeStyleFeatureType ADMINISTRATIVE_COUNTRY =
      create("administrative.country");

  /**
   * Apply the rule to land parcels.
   */
  public static final MapTypeStyleFeatureType ADMINISTRATIVE_LAND_PARCEL =
      create("administrative.land_parcel");

  /**
   * Apply the rule to localities.
   */
  public static final MapTypeStyleFeatureType ADMINISTRATIVE_LOCALITY =
      create("administrative.locality");

  /**
   * Apply the rule to neighborhoods.
   */
  public static final MapTypeStyleFeatureType ADMINISTRATIVE_NEIGHBORHOOD =
      create("administrative.neighborhood");

  /**
   * Apply the rule to provinces.
   */
  public static final MapTypeStyleFeatureType ADMINISTRATIVE_PROVINCE =
      create("administrative.province");

  /**
   * Apply the rule to all selector types.
   */
  public static final MapTypeStyleFeatureType ALL = create("all");

  /**
   * Apply the rule to landscapes.
   */
  public static final MapTypeStyleFeatureType LANDSCAPE = create("landscape");

  /**
   * Apply the rule to man made structures.
   */
  public static final MapTypeStyleFeatureType LANDSCAPE_MAN_MADE =
      create("landscape.man_made");

  /**
   * Apply the rule to natural features.
   */
  public static final MapTypeStyleFeatureType LANDSCAPE_NATURAL =
      create("landscape.natural");

  /**
   * Apply the rule to points of interest.
   */
  public static final MapTypeStyleFeatureType POI = create("poi");

  /**
   * Apply the rule to attractions for tourists.
   */
  public static final MapTypeStyleFeatureType POI_ATTRACTION =
      create("poi.attraction");

  /**
   * Apply the rule to businesses.
   */
  public static final MapTypeStyleFeatureType POI_BUSINESS =
      create("poi.business");

  /**
   * Apply the rule to government buildings.
   */
  public static final MapTypeStyleFeatureType POI_GOVERNMENT =
      create("poi.government");

  /**
   * Apply the rule to emergency services (hospitals, pharmacies, police,
  doctors, etc).
   */
  public static final MapTypeStyleFeatureType POI_MEDICAL =
      create("poi.medical");

  /**
   * Apply the rule to parks.
   */
  public static final MapTypeStyleFeatureType POI_PARK = create("poi.park");

  /**
   * Apply the rule to places of worship, such as church, temple, or
  mosque.
   */
  public static final MapTypeStyleFeatureType POI_PLACE_OF_WORSHIP =
      create("poi.place_of_worship");

  /**
   * Apply the rule to schools.
   */
  public static final MapTypeStyleFeatureType POI_SCHOOL = create("poi.school");

  /**
   * Apply the rule to sports complexes.
   */
  public static final MapTypeStyleFeatureType POI_SPORTS_COMPLEX =
      create("poi.sports_complex");

  /**
   * Apply the rule to all roads.
   */
  public static final MapTypeStyleFeatureType ROAD = create("road");

  /**
   * Apply the rule to arterial roads.
   */
  public static final MapTypeStyleFeatureType ROAD_ARTERIAL =
      create("road.arterial");

  /**
   * Apply the rule to highways.
   */
  public static final MapTypeStyleFeatureType ROAD_HIGHWAY =
      create("road.highway");

  /**
   * Apply the rule to local roads.
   */
  public static final MapTypeStyleFeatureType ROAD_LOCAL = create("road.local");

  /**
   * Apply the rule to all transit stations and lines.
   */
  public static final MapTypeStyleFeatureType TRANSIT =  create("transit");

  /**
   * Apply the rule to transit lines.
   */
  public static final MapTypeStyleFeatureType TRANSIT_LINE =
      create("transit.line");

  /**
   * Apply the rule to all transit stations.
   */
  public static final MapTypeStyleFeatureType TRANSIT_STATION =
      create("transit.station");

  /**
   * Apply the rule to airports.
   */
  public static final MapTypeStyleFeatureType TRANSIT_STATION_AIRPORT =
      create("transit.station.airport");

  /**
   * Apply the rule to bus stops.
   */
  public static final MapTypeStyleFeatureType TRANSIT_STATION_BUS =
      create("transit.station.bus");

  /**
   * Apply the rule to rail stations.
   */
  public static final MapTypeStyleFeatureType TRANSIT_STATION_RAIL =
      create("transit.station.rail");

  /**
   * Apply the rule to bodies of water.
   */
  public static final MapTypeStyleFeatureType WATER = create("water");

  private static java.util.Map<String, MapTypeStyleFeatureType> registry =
      new HashMap<String, MapTypeStyleFeatureType>();

  /**
   * Internal initialization method.
   */
  private static final native MapTypeStyleFeatureType create(String value)/*-{
    instance = {
      'value' : value
    };
    @com.google.maps.gwt.client.MapTypeStyleFeatureType::register(Lcom/google/maps/gwt/client/MapTypeStyleFeatureType;)(instance);
    return instance;
  }-*/;

  private static final MapTypeStyleFeatureType fromValue(String value) {
    return registry.get(value);
  }

  private static final void register(MapTypeStyleFeatureType value) {
    registry.put(value.getValue(), value);
  }

  /**
   * Protected constructor for internal use only.
   */
  protected MapTypeStyleFeatureType() {
    /* Java constructor is protected, */
  }

  private final native String getValue() /*-{
    return this.value;
  }-*/;
}

