/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;

/**
 * A styler affects how a map's elements will be styled.  Each
 * <code>MapTypeStyler</code>
 * 
 * should contain one and only one key. If more than one key is specified in a single 
 * <code>MapTypeStyler</code>
 * 
 * , all but one will be ignored.  For example:
 * <code>var rule = {hue: '#ff0000'}</code>
 * 
 * .
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class MapTypeStyler extends JavaScriptObject {

  /**
   * Gamma. Modifies the gamma by raising the lightness to the given
   * power. Valid values: Floating point numbers, [0.01, 10], with 1.0
   * representing no change.
   */ 
  public static final native MapTypeStyler gamma(double gamma)/*-{
    return { gamma: gamma };
  }-*/;

  /**
   * Sets the hue of the feature to match the hue of the color supplied.
   * Note that the saturation and lightness of the feature is conserved,
   * which means that the feature will not match the color supplied
   * exactly.  Valid values: An RGB hex string, i.e.
   * <code>'#ff0000'</code>
   * 
   * .
   */ 
  public static final native MapTypeStyler hue(String hue)/*-{
    return { hue: hue };
  }-*/;

  /**
   * Inverts lightness. A value of 
   * <code>true</code>
   * 
   * will invert the lightness of the feature while preserving the hue and saturation.
   */ 
  public static final native MapTypeStyler invert_lightness(boolean invert_lightness)/*-{
    return { invert_lightness: invert_lightness };
  }-*/;

  /**
   * Lightness. Shifts lightness of colors by a percentage of the original
   * value if decreasing and a percentage of the remaining value if
   * increasing. Valid values: [-100, 100].
   */ 
  public static final native MapTypeStyler lightness(double lightness)/*-{
    return { lightness: lightness };
  }-*/;

  /**
   * Saturation. Shifts the saturation of colors by a percentage of the
   * original value if decreasing and a percentage of the remaining value
   * if increasing. Valid values: [-100, 100].
   */ 
  public static final native MapTypeStyler saturation(double saturation)/*-{
    return { saturation: saturation };
  }-*/;

  /**
   * Visibility: Valid values: 'on', 'off' or 'simplifed'.
   */ 
  public static final native MapTypeStyler visibility(String visibility)/*-{
    return { visibility: visibility };
  }-*/;


  /**
   * Protected constructor avoids default public constructor.
   */
  protected MapTypeStyler() {
    /* Java constructor is protected, */
  }

}

