/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;

/**
 * 
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class Marker extends MVCObject {

  /**
   * This event is fired when the marker's animation property changes.
   */
  public interface AnimationChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the marker icon was clicked.
   */
  public interface ClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the marker's clickable property changes.
   */
  public interface ClickableChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the marker's cursor property changes.
   */
  public interface CursorChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the marker icon was double clicked.
   */
  public interface DblClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the user stops dragging the marker.
   */
  public interface DragEndHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is repeatedly fired while the user drags the marker.
   */
  public interface DragHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the user starts dragging the marker.
   */
  public interface DragStartHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the marker's draggable property changes.
   */
  public interface DraggableChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the marker's flat property changes.
   */
  public interface FlatChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the marker icon property changes.
   */
  public interface IconChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired for a mousedown on the marker.
   */
  public interface MouseDownHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the mouse leaves the area of the marker icon.
   */
  public interface MouseOutHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the mouse enters the area of the marker icon.
   */
  public interface MouseOverHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired for a mouseup on the marker.
   */
  public interface MouseUpHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the marker position property changes.
   */
  public interface PositionChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired for a rightclick on the marker.
   */
  public interface RightClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the marker's shadow property changes.
   */
  public interface ShadowChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the marker's shape property changes.
   */
  public interface ShapeChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the marker title property changes.
   */
  public interface TitleChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the marker's visible property changes.
   */
  public interface VisibleChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the marker's zIndex property changes.
   */
  public interface ZIndexChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * The maximum default z-index that the API will assign to a marker. You
   * may set a higher z-index to bring a marker to the front.
   */ 
  public static final double MAX_ZINDEX = getMaxZindex();

  /**
   * Creates a marker with the options specified. If a map is specified,
   * the marker is added to the map upon construction. Note that the
   * position must be set for the marker to display.
   */ 
  public static native Marker create(MarkerOptions opts)/*-{
    var _opts;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _opts = opts;
    } else {
      _opts = {};
      for(k in opts) {
        if(k != "__gwt_ObjectId") {
          _opts[k] = opts[k];
        }
      }
    } 
    return new $wnd.google.maps.Marker(_opts);
  }-*/;

  /**
   * Creates a marker with the options specified. If a map is specified,
   * the marker is added to the map upon construction. Note that the
   * position must be set for the marker to display.
   */ 
  public static native Marker create()/*-{
    return new $wnd.google.maps.Marker();
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native double getMaxZindex()/*-{
    return $wnd.google.maps.Marker.MAX_ZINDEX;
  }-*/;


  /**
   * Protected constructor avoids default public constructor.
   */
  protected Marker() {
    /* Java constructor is protected, */
  }

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addAnimationChangedListener(AnimationChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.AnimationChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "animation_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addAnimationChangedListenerOnce(AnimationChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.AnimationChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "animation_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addClickListener(ClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.ClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "click", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addClickListenerOnce(ClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.ClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "click", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addClickableChangedListener(ClickableChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.ClickableChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "clickable_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addClickableChangedListenerOnce(ClickableChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.ClickableChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "clickable_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addCursorChangedListener(CursorChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.CursorChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "cursor_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addCursorChangedListenerOnce(CursorChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.CursorChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "cursor_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addDblClickListener(DblClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.DblClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "dblclick", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addDblClickListenerOnce(DblClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.DblClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "dblclick", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addDragEndListener(DragEndHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.DragEndHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "dragend", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addDragEndListenerOnce(DragEndHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.DragEndHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "dragend", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addDragListener(DragHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.DragHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "drag", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addDragListenerOnce(DragHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.DragHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "drag", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addDragStartListener(DragStartHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.DragStartHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "dragstart", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addDragStartListenerOnce(DragStartHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.DragStartHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "dragstart", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addDraggableChangedListener(DraggableChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.DraggableChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "draggable_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addDraggableChangedListenerOnce(DraggableChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.DraggableChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "draggable_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addFlatChangedListener(FlatChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.FlatChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "flat_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addFlatChangedListenerOnce(FlatChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.FlatChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "flat_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addIconChangedListener(IconChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.IconChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "icon_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addIconChangedListenerOnce(IconChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.IconChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "icon_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseDownListener(MouseDownHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.MouseDownHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mousedown", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseDownListenerOnce(MouseDownHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.MouseDownHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mousedown", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseOutListener(MouseOutHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.MouseOutHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mouseout", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseOutListenerOnce(MouseOutHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.MouseOutHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mouseout", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseOverListener(MouseOverHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.MouseOverHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mouseover", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseOverListenerOnce(MouseOverHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.MouseOverHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mouseover", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseUpListener(MouseUpHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.MouseUpHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mouseup", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseUpListenerOnce(MouseUpHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.MouseUpHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mouseup", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addPositionChangedListener(PositionChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.PositionChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "position_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addPositionChangedListenerOnce(PositionChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.PositionChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "position_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addRightClickListener(RightClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.RightClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "rightclick", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addRightClickListenerOnce(RightClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Marker.RightClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "rightclick", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addShadowChangedListener(ShadowChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.ShadowChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "shadow_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addShadowChangedListenerOnce(ShadowChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.ShadowChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "shadow_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addShapeChangedListener(ShapeChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.ShapeChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "shape_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addShapeChangedListenerOnce(ShapeChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.ShapeChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "shape_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addTitleChangedListener(TitleChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.TitleChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "title_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addTitleChangedListenerOnce(TitleChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.TitleChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "title_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addVisibleChangedListener(VisibleChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.VisibleChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "visible_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addVisibleChangedListenerOnce(VisibleChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.VisibleChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "visible_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addZIndexChangedListener(ZIndexChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.ZIndexChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "zindex_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addZIndexChangedListenerOnce(ZIndexChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Marker.ZIndexChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "zindex_changed", _handler);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearAnimationChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "animation_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "click");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearClickableChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "clickable_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearCursorChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "cursor_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearDblClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "dblclick");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearDragEndListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "dragend");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearDragListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "drag");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearDragStartListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "dragstart");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearDraggableChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "draggable_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearFlatChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "flat_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearIconChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "icon_changed");
  }-*/;

  /**
   * Removes all listeners for all events for the given instance.
   */ 
  public final native void clearInstanceListeners()/*-{
    $wnd.google.maps.event.clearInstanceListeners(this);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseDownListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mousedown");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseOutListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mouseout");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseOverListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mouseover");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseUpListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mouseup");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearPositionChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "position_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearRightClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "rightclick");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearShadowChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "shadow_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearShapeChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "shape_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearTitleChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "title_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearVisibleChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "visible_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearZIndexChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "zindex_changed");
  }-*/;

  public final native Animation getAnimation()/*-{
    var _retval = this.getAnimation();
    var retval = (_retval == undefined) ?
        null : @com.google.maps.gwt.client.Animation::fromValue(D)(_retval);
    return retval;
  }-*/;

  public final native boolean getClickable()/*-{
    return this.getClickable();

  }-*/;

  public final native String getCursor()/*-{
    return this.getCursor();

  }-*/;

  public final native boolean getDraggable()/*-{
    return this.getDraggable();

  }-*/;

  public final native boolean getFlat()/*-{
    return this.getFlat();

  }-*/;

  public final native LatLng getPosition()/*-{
    return this.getPosition();

  }-*/;

  public final native MarkerShape getShape()/*-{
    var _retval = this.getShape();
    var retval = _retval;
    return retval;
  }-*/;

  public final native String getTitle()/*-{
    return this.getTitle();

  }-*/;

  public final native boolean getVisible()/*-{
    return this.getVisible();

  }-*/;

  public final native double getZIndex()/*-{
    return this.getZIndex();

  }-*/;

  /**
   * Start an animation. Any ongoing animation will be cancelled.
   * Currently supported animations are: BOUNCE, DROP. Passing in
   * <code>null</code>
   * 
   * will cause any animation to stop.
   */ 
  public final native void setAnimation(Animation animation)/*-{
    var _animation = animation == undefined ? null : animation.value; 
    this.setAnimation(_animation);

  }-*/;

  /**
   * Start an animation. Any ongoing animation will be cancelled.
   * Currently supported animations are: BOUNCE, DROP. Passing in
   * <code>null</code>
   * 
   * will cause any animation to stop.
   */ 
  public final native void setAnimation()/*-{
    this.setAnimation();

  }-*/;

  public final native void setClickable(boolean flag)/*-{
    this.setClickable(flag);

  }-*/;

  public final native void setCursor(String cursor)/*-{
    this.setCursor(cursor);

  }-*/;

  public final native void setDraggable(boolean flag)/*-{
    this.setDraggable(flag);

  }-*/;

  public final native void setDraggable()/*-{
    this.setDraggable();

  }-*/;

  public final native void setFlat(boolean flag)/*-{
    this.setFlat(flag);

  }-*/;

  public final native void setIcon(String icon)/*-{
    this.setIcon(icon);

  }-*/;

  public final native void setIcon(MarkerImage icon)/*-{
    this.setIcon(icon);

  }-*/;

  /**
   * Renders the marker on the specified map or panorama.  If map is set
   * to null, the marker will be removed.
   */ 
  public final native void setMap(GoogleMap map)/*-{
    this.setMap(map);

  }-*/;

  /**
   * Renders the marker on the specified map or panorama.  If map is set
   * to null, the marker will be removed.
   */ 
  public final native void setMap(StreetViewPanorama map)/*-{
    this.setMap(map);

  }-*/;

  public final native void setOptions(MarkerOptions options)/*-{
    var _options;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _options = options;
    } else {
      _options = {};
      for(k in options) {
        if(k != "__gwt_ObjectId") {
          _options[k] = options[k];
        }
      }
    } 
    this.setOptions(_options);

  }-*/;

  public final native void setPosition(LatLng latlng)/*-{
    this.setPosition(latlng);

  }-*/;

  public final native void setShadow(String shadow)/*-{
    this.setShadow(shadow);

  }-*/;

  public final native void setShadow(MarkerImage shadow)/*-{
    this.setShadow(shadow);

  }-*/;

  public final native void setShape(MarkerShape shape)/*-{
    var _shape;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _shape = shape;
    } else {
      _shape = {};
      for(k in shape) {
        if(k != "__gwt_ObjectId") {
          _shape[k] = shape[k];
        }
      }
    } 
    this.setShape(_shape);

  }-*/;

  public final native void setTitle(String title)/*-{
    this.setTitle(title);

  }-*/;

  public final native void setVisible(boolean visible)/*-{
    this.setVisible(visible);

  }-*/;

  public final native void setZIndex(double zIndex)/*-{
    this.setZIndex(zIndex);

  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerAnimationChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "animation_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "click", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerClickableChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "clickable_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerCursorChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "cursor_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerDblClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "dblclick", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerDrag(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "drag", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerDragEnd(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "dragend", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerDragStart(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "dragstart", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerDraggableChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "draggable_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerFlatChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "flat_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerIconChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "icon_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseDown(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mousedown", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseOut(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mouseout", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseOver(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mouseover", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseUp(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mouseup", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerPositionChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "position_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerRightClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "rightclick", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerShadowChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "shadow_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerShapeChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "shape_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerTitleChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "title_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerVisibleChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "visible_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerZIndexChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "zindex_changed", _varargs);
  }-*/;

}

