/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;

/**
 * 
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class MarkerOptions extends JavaScriptObject {

  public static final MarkerOptions create(){
    return JavaScriptObject.createObject().cast();
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected MarkerOptions() {
    /* Java constructor is protected, */
  }

  /**
   * Which animation to play when marker is added to a map.
   */ 
  public final native void setAnimation(Animation animation)/*-{
    var _animation = animation == undefined ? null : animation.value; 
    this.animation = _animation;
  }-*/;

  /**
   * If true, the marker receives mouse and touch events.  Default value is true.
   */ 
  public final native void setClickable(boolean clickable)/*-{
    this.clickable = clickable;
  }-*/;

  /**
   * Mouse cursor to show on hover
   */ 
  public final native void setCursor(String cursor)/*-{
    this.cursor = cursor;
  }-*/;

  /**
   * If true, the marker can be dragged.  Default value is false.
   */ 
  public final native void setDraggable(boolean draggable)/*-{
    this.draggable = draggable;
  }-*/;

  /**
   * If true, the marker shadow will not be displayed.
   */ 
  public final native void setFlat(boolean flat)/*-{
    this.flat = flat;
  }-*/;

  /**
   * Icon for the foreground
   */ 
  public final native void setIcon(String icon)/*-{
    this.icon = icon;
  }-*/;

  /**
   * Icon for the foreground
   */ 
  public final native void setIcon(MarkerImage icon)/*-{
    this.icon = icon;
  }-*/;

  /**
   * Map on which to display Marker.
   */ 
  public final native void setMap(GoogleMap map)/*-{
    this.map = map;
  }-*/;

  /**
   * Map on which to display Marker.
   */ 
  public final native void setMap(StreetViewPanorama map)/*-{
    this.map = map;
  }-*/;

  /**
   * Optimization renders many markers as a single static element.
   * Optimized rendering is enabled by default. Disable optimized
   * rendering for animated GIFs or PNGs, or when each marker must be
   * rendered as a separate DOM element (advanced usage only).
   */ 
  public final native void setOptimized(boolean optimized)/*-{
    this.optimized = optimized;
  }-*/;

  /**
   * Marker position. Required.
   */ 
  public final native void setPosition(LatLng position)/*-{
    this.position = position;
  }-*/;

  /**
   * If false, disables raising and lowering the marker on drag.  This option is 
   * <code>true</code>
   * 
   * by default.
   */ 
  public final native void setRaiseOnDrag(boolean raiseOnDrag)/*-{
    this.raiseOnDrag = raiseOnDrag;
  }-*/;

  /**
   * Shadow image
   */ 
  public final native void setShadow(String shadow)/*-{
    this.shadow = shadow;
  }-*/;

  /**
   * Shadow image
   */ 
  public final native void setShadow(MarkerImage shadow)/*-{
    this.shadow = shadow;
  }-*/;

  /**
   * Image map region definition used for drag/click.
   */ 
  public final native void setShape(MarkerShape shape)/*-{
    var _shape;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _shape = shape;
    } else {
      _shape = {};
      for(k in shape) {
        if(k != "__gwt_ObjectId") {
          _shape[k] = shape[k];
        }
      }
    } 
    this.shape = _shape;
  }-*/;

  /**
   * Rollover text
   */ 
  public final native void setTitle(String title)/*-{
    this.title = title;
  }-*/;

  /**
   * If true, the marker is visible
   */ 
  public final native void setVisible(boolean visible)/*-{
    this.visible = visible;
  }-*/;

  /**
   * All markers are displayed on the map in order of their zIndex, with
   * higher values displaying in front of markers with lower values.  By
   * default, markers are displayed according to their vertical position
   * on screen, with lower markers appearing in front of markers further
   * up the screen.
   */ 
  public final native void setZindex(double zIndex)/*-{
    this.zIndex = zIndex;
  }-*/;

}

