/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArrayNumber;

/**
 * This object defines the marker shape to use in determination of a
 * marker's clickable region.  The shape consists of two properties
 * &mdash;
 * <code>type</code>
 * 
 *  and 
 * <code>coord</code>
 * 
 * &mdash; which define the general type of marker and coordinates
 * specific to that type of marker.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class MarkerShape extends JavaScriptObject {

  public static final MarkerShape create(){
    return JavaScriptObject.createObject().cast();
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected MarkerShape() {
    /* Java constructor is protected, */
  }

  /**
   * The format of this attribute depends on the value of the
   * <code>type</code>
   * 
   *  and follows the w3 AREA 
   * <code>coords</code>
   * 
   * specification found at <a href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-coords">
   * http://www.w3.org/TR/REC-html40/struct/objects.html#adef-coords</a>.
   * <br>The
   * <code>coords</code>
   * 
   * attribute is an array of integers that specify the pixel position of
   * the shape relative to the top-left corner of the target image.  The
   * coordinates depend on the value of
   * <code>type</code>
   * 
   * as follows: <br>&nbsp;&nbsp;- 
   * <code>circle</code>
   * 
   * : coords is 
   * <code>[x1,y1,r]</code>
   * 
   * where x1,y2 are the coordinates of the center of the circle, and r is
   * the radius of the circle. <br>&nbsp;&nbsp;-
   * <code>poly</code>
   * 
   * : coords is
   * <code>[x1,y1,x2,y2...xn,yn]</code>
   * 
   * where each x,y pair contains the coordinates of one vertex of the
   * polygon. <br>&nbsp;&nbsp;-
   * <code>rect</code>
   * 
   * : coords is 
   * <code>[x1,y1,x2,y2]</code>
   * 
   * where x1,y1 are the coordinates of the upper-left corner of the
   * rectangle and x2,y2 are the coordinates of the lower-right
   * coordinates of the rectangle.
   */ 
  public final native void setCoords(JsArrayNumber coords)/*-{
    this.coords = coords;
  }-*/;

  /**
   * Describes the shape's type and can be 
   * <code>circle</code>
   * 
   * ,
   * <code>poly</code>
   * 
   *  or 
   * <code>rect</code>
   * 
   * .
   */ 
  public final native void setType(String type)/*-{
    this.type = type;
  }-*/;

}

