/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;

/**
 * A service for obtaining the highest zoom level at which satellite
 * imagery is available for a given location.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class MaxZoomService extends JavaScriptObject {

  /**
   * Callback type for handling asynchronous responses from getMaxZoomAtLatLng.
   */
  public interface Callback  {

    /**
     * Called by the callback handler
     */ 
    void handle(MaxZoomResult a);
  }

  /**
   * Creates a new instance of a 
   * <code>MaxZoomService</code>
   * 
   * that can be used to send queries about the maximum zoom level
   * available for satellite imagery.
   */ 
  public static native MaxZoomService create()/*-{
    return new $wnd.google.maps.MaxZoomService();
  }-*/;


  /**
   * Protected constructor avoids default public constructor.
   */
  protected MaxZoomService() {
    /* Java constructor is protected, */
  }

  /**
   * Returns the maximum zoom level available at a particular 
   * <code>LatLng</code>
   * 
   * for the Satellite map type. As this request is asynchronous, you must pass a
   * <code>callback</code>
   * 
   * function which will be executed upon completion of the request, being passed a 
   * <code>MaxZoomResult</code>
   * 
   * .
   */ 
  public final native void getMaxZoomAtLatLng(LatLng latlng, Callback callback)/*-{
    var _callback = $entry(function(a) {
      callback.@com.google.maps.gwt.client.MaxZoomService.Callback::handle(Lcom/google/maps/gwt/client/MaxZoomResult;)(a);

    }); 
    this.getMaxZoomAtLatLng(latlng, _callback);

  }-*/;

}

