/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * Identifiers for common types of navigation controls.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class NavigationControlStyle extends JavaScriptObject {

  /**
   * The small zoom control similar to the one used by the native Maps
   * application on Android.
   */ 
  public static final NavigationControlStyle ANDROID = getAndroid();

  /**
   * The default navigation control. The control which DEFAULT maps to
   * will vary according to map size and other factors. It may change in
   * future versions of the API.
   */ 
  public static final NavigationControlStyle DEFAULT = getDefault();

  /**
   * The small, zoom only control.
   */ 
  public static final NavigationControlStyle SMALL = getSmall();

  /**
   * The larger control, with the zoom slider and pan directional pad.
   */ 
  public static final NavigationControlStyle ZOOM_PAN = getZoomPan();

  /**
   * Internal registry for value types.
   */ 
  private static Map<Double,NavigationControlStyle> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final NavigationControlStyle fromValue(double value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native NavigationControlStyle getAndroid()/*-{
    var instance = { 'value' : $wnd.google.maps.NavigationControlStyle.ANDROID };
    @com.google.maps.gwt.client.NavigationControlStyle::register(Lcom/google/maps/gwt/client/NavigationControlStyle;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native NavigationControlStyle getDefault()/*-{
    var instance = { 'value' : $wnd.google.maps.NavigationControlStyle.DEFAULT };
    @com.google.maps.gwt.client.NavigationControlStyle::register(Lcom/google/maps/gwt/client/NavigationControlStyle;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native NavigationControlStyle getSmall()/*-{
    var instance = { 'value' : $wnd.google.maps.NavigationControlStyle.SMALL };
    @com.google.maps.gwt.client.NavigationControlStyle::register(Lcom/google/maps/gwt/client/NavigationControlStyle;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native NavigationControlStyle getZoomPan()/*-{
    var instance = { 'value' : $wnd.google.maps.NavigationControlStyle.ZOOM_PAN };
    @com.google.maps.gwt.client.NavigationControlStyle::register(Lcom/google/maps/gwt/client/NavigationControlStyle;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(NavigationControlStyle value){
    if (registry == null) {
      registry = new HashMap<Double, NavigationControlStyle>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected NavigationControlStyle() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native double getValue()/*-{
    return this.value;
  }-*/;

}

