/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArray;

/**
 * An elevation query sent by the 
 * <code>ElevationService</code>
 * 
 * containing the path along which to return sampled data. This request
 * defines a continuous path along the earth along which elevation
 * samples should be taken at evenly-spaced distances. All paths from
 * vertex to vertex use segments of the great circle between those two
 * points.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class PathElevationRequest extends JavaScriptObject {

  public static final PathElevationRequest create(){
    return JavaScriptObject.createObject().cast();
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected PathElevationRequest() {
    /* Java constructor is protected, */
  }

  /**
   * The path along which to collect elevation values.
   */ 
  public final native void setPath(JsArray<LatLng> path)/*-{
    this.path = path;
  }-*/;

  /**
   * Required. The number of equidistant points along the given path for
   * which to retrieve elevation data, including the endpoints. The number
   * of samples must be a value between 2 and 1024.
   */ 
  public final native void setSamples(double samples)/*-{
    this.samples = samples;
  }-*/;

}

