/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArray;

/**
 * A polyline is a linear overlay of connected line segments on the map.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class Polyline extends MVCObject {

  /**
   * This event is fired when the DOM click event is fired on the Polyline.
   */
  public interface ClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the DOM dblclick event is fired on the Polyline.
   */
  public interface DblClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the DOM mousedown event is fired on the Polyline.
   */
  public interface MouseDownHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the DOM mousemove event is fired on the Polyline.
   */
  public interface MouseMoveHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired on Polyline mouseout.
   */
  public interface MouseOutHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired on Polyline mouseover.
   */
  public interface MouseOverHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the DOM mouseup event is fired on the Polyline.
   */
  public interface MouseUpHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the Polyline is right-clicked on.
   */
  public interface RightClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * Create a polyline using the passed
   * <code><em><a href="#PolylineOptions">PolylineOptions</a></em></code>
   * 
   * , which specify both the path of the polyline and the stroke style to
   * use when drawing the polyline. You may pass either an array of
   * <code>LatLng</code>
   * 
   * s or an
   * <code><a href="#MVCArray">MVCArray</a></code>
   * 
   *  of 
   * <code>LatLng</code>
   * 
   * s when constructing a polyline, though simple arrays are converted to
   * <code>MVCArray</code>
   * 
   * s within the polyline upon instantiation.
   */ 
  public static native Polyline create(PolylineOptions opts)/*-{
    var _opts;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _opts = opts;
    } else {
      _opts = {};
      for(k in opts) {
        if(k != "__gwt_ObjectId") {
          _opts[k] = opts[k];
        }
      }
    } 
    return new $wnd.google.maps.Polyline(_opts);
  }-*/;

  /**
   * Create a polyline using the passed
   * <code><em><a href="#PolylineOptions">PolylineOptions</a></em></code>
   * 
   * , which specify both the path of the polyline and the stroke style to
   * use when drawing the polyline. You may pass either an array of
   * <code>LatLng</code>
   * 
   * s or an
   * <code><a href="#MVCArray">MVCArray</a></code>
   * 
   *  of 
   * <code>LatLng</code>
   * 
   * s when constructing a polyline, though simple arrays are converted to
   * <code>MVCArray</code>
   * 
   * s within the polyline upon instantiation.
   */ 
  public static native Polyline create()/*-{
    return new $wnd.google.maps.Polyline();
  }-*/;


  /**
   * Protected constructor avoids default public constructor.
   */
  protected Polyline() {
    /* Java constructor is protected, */
  }

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addClickListener(ClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.ClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "click", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addClickListenerOnce(ClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.ClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "click", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addDblClickListener(DblClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.DblClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "dblclick", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addDblClickListenerOnce(DblClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.DblClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "dblclick", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseDownListener(MouseDownHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.MouseDownHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mousedown", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseDownListenerOnce(MouseDownHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.MouseDownHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mousedown", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseMoveListener(MouseMoveHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.MouseMoveHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mousemove", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseMoveListenerOnce(MouseMoveHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.MouseMoveHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mousemove", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseOutListener(MouseOutHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.MouseOutHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mouseout", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseOutListenerOnce(MouseOutHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.MouseOutHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mouseout", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseOverListener(MouseOverHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.MouseOverHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mouseover", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseOverListenerOnce(MouseOverHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.MouseOverHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mouseover", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseUpListener(MouseUpHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.MouseUpHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mouseup", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseUpListenerOnce(MouseUpHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.MouseUpHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mouseup", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addRightClickListener(RightClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.RightClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "rightclick", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addRightClickListenerOnce(RightClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Polyline.RightClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "rightclick", _handler);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "click");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearDblClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "dblclick");
  }-*/;

  /**
   * Removes all listeners for all events for the given instance.
   */ 
  public final native void clearInstanceListeners()/*-{
    $wnd.google.maps.event.clearInstanceListeners(this);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseDownListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mousedown");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseMoveListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mousemove");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseOutListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mouseout");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseOverListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mouseover");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseUpListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mouseup");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearRightClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "rightclick");
  }-*/;

  /**
   * Returns whether this shape can be edited by the user.
   */ 
  public final native boolean getEditable()/*-{
    return this.getEditable();

  }-*/;

  /**
   * Returns the map on which this shape is attached.
   */ 
  public final native GoogleMap getMap()/*-{
    return this.getMap();

  }-*/;

  /**
   * Retrieves the first path.
   */ 
  public final native MVCArray<LatLng> getPath()/*-{
    return this.getPath();

  }-*/;

  /**
   * Returns whether this poly is visible on the map.
   */ 
  public final native boolean getVisible()/*-{
    return this.getVisible();

  }-*/;

  /**
   * If set to true, the user can edit this shape by dragging the control
   * points shown at the vertices and on each segment.
   */ 
  public final native void setEditable(boolean editable)/*-{
    this.setEditable(editable);

  }-*/;

  /**
   * Renders this shape on the specified map.  If map is set to null, the
   * shape will be removed.
   */ 
  public final native void setMap(GoogleMap map)/*-{
    this.setMap(map);

  }-*/;

  public final native void setOptions(PolylineOptions options)/*-{
    var _options;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _options = options;
    } else {
      _options = {};
      for(k in options) {
        if(k != "__gwt_ObjectId") {
          _options[k] = options[k];
        }
      }
    } 
    this.setOptions(_options);

  }-*/;

  /**
   * Sets the first path.  See <em>
   * <code><a
   * href="#PolylineOptions">PolylineOptions</a></code>
   * 
   * </em> for more details.
   */ 
  public final native void setPath(MVCArray<LatLng> path)/*-{
    this.setPath(path);

  }-*/;

  /**
   * Sets the first path.  See <em>
   * <code><a
   * href="#PolylineOptions">PolylineOptions</a></code>
   * 
   * </em> for more details.
   */ 
  public final native void setPath(JsArray<LatLng> path)/*-{
    this.setPath(path);

  }-*/;

  /**
   * Hides this poly if set to 
   * <code>false</code>
   * 
   * .
   */ 
  public final native void setVisible(boolean visible)/*-{
    this.setVisible(visible);

  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "click", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerDblClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "dblclick", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseDown(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mousedown", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseMove(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mousemove", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseOut(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mouseout", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseOver(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mouseover", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseUp(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mouseup", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerRightClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "rightclick", _varargs);
  }-*/;

}

