/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;

/**
 * A rectangle overlay.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class Rectangle extends MVCObject {

  /**
   * This event is fired when the rectangle's bounds are changed.
   */
  public interface BoundsChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * This event is fired when the DOM click event is fired on the rectangle.
   */
  public interface ClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the DOM dblclick event is fired on the rectangle.
   */
  public interface DblClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the DOM mousedown event is fired on the rectangle.
   */
  public interface MouseDownHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the DOM mousemove event is fired on the rectangle.
   */
  public interface MouseMoveHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired on rectangle mouseout.
   */
  public interface MouseOutHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired on rectangle mouseover.
   */
  public interface MouseOverHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the DOM mouseup event is fired on the rectangle.
   */
  public interface MouseUpHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * This event is fired when the rectangle is right-clicked on.
   */
  public interface RightClickHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(MouseEvent event);
  }

  /**
   * Create a rectangle using the passed
   * <code><em><a href="#RectangleOptions">RectangleOptions</a></em></code>
   * 
   * , which specify the bounds and style.
   */ 
  public static native Rectangle create(RectangleOptions opts)/*-{
    var _opts;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _opts = opts;
    } else {
      _opts = {};
      for(k in opts) {
        if(k != "__gwt_ObjectId") {
          _opts[k] = opts[k];
        }
      }
    } 
    return new $wnd.google.maps.Rectangle(_opts);
  }-*/;

  /**
   * Create a rectangle using the passed
   * <code><em><a href="#RectangleOptions">RectangleOptions</a></em></code>
   * 
   * , which specify the bounds and style.
   */ 
  public static native Rectangle create()/*-{
    return new $wnd.google.maps.Rectangle();
  }-*/;


  /**
   * Protected constructor avoids default public constructor.
   */
  protected Rectangle() {
    /* Java constructor is protected, */
  }

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addBoundsChangedListener(BoundsChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Rectangle.BoundsChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "bounds_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addBoundsChangedListenerOnce(BoundsChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.Rectangle.BoundsChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "bounds_changed", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addClickListener(ClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.ClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "click", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addClickListenerOnce(ClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.ClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "click", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addDblClickListener(DblClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.DblClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "dblclick", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addDblClickListenerOnce(DblClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.DblClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "dblclick", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseDownListener(MouseDownHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.MouseDownHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mousedown", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseDownListenerOnce(MouseDownHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.MouseDownHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mousedown", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseMoveListener(MouseMoveHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.MouseMoveHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mousemove", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseMoveListenerOnce(MouseMoveHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.MouseMoveHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mousemove", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseOutListener(MouseOutHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.MouseOutHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mouseout", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseOutListenerOnce(MouseOutHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.MouseOutHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mouseout", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseOverListener(MouseOverHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.MouseOverHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mouseover", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseOverListenerOnce(MouseOverHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.MouseOverHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mouseover", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMouseUpListener(MouseUpHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.MouseUpHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "mouseup", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMouseUpListenerOnce(MouseUpHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.MouseUpHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "mouseup", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addRightClickListener(RightClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.RightClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "rightclick", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addRightClickListenerOnce(RightClickHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.Rectangle.RightClickHandler::handle(Lcom/google/maps/gwt/client/MouseEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "rightclick", _handler);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearBoundsChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "bounds_changed");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "click");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearDblClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "dblclick");
  }-*/;

  /**
   * Removes all listeners for all events for the given instance.
   */ 
  public final native void clearInstanceListeners()/*-{
    $wnd.google.maps.event.clearInstanceListeners(this);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseDownListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mousedown");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseMoveListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mousemove");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseOutListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mouseout");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseOverListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mouseover");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMouseUpListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "mouseup");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearRightClickListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "rightclick");
  }-*/;

  /**
   * Returns the bounds of this rectangle.
   */ 
  public final native LatLngBounds getBounds()/*-{
    return this.getBounds();

  }-*/;

  /**
   * Returns whether this rectangle can be edited by the user.
   */ 
  public final native boolean getEditable()/*-{
    return this.getEditable();

  }-*/;

  /**
   * Returns the map on which this rectangle is displayed.
   */ 
  public final native GoogleMap getMap()/*-{
    return this.getMap();

  }-*/;

  /**
   * Returns whether this rectangle is visible on the map.
   */ 
  public final native boolean getVisible()/*-{
    return this.getVisible();

  }-*/;

  /**
   * Sets the bounds of this rectangle.
   */ 
  public final native void setBounds(LatLngBounds bounds)/*-{
    this.setBounds(bounds);

  }-*/;

  /**
   * If set to true, the user can edit this rectangle by dragging the
   * control points shown at the corners and on each edge.
   */ 
  public final native void setEditable(boolean editable)/*-{
    this.setEditable(editable);

  }-*/;

  /**
   * Renders the rectangle on the specified map.  If map is set to null,
   * the rectangle will be removed.
   */ 
  public final native void setMap(GoogleMap map)/*-{
    this.setMap(map);

  }-*/;

  public final native void setOptions(RectangleOptions options)/*-{
    var _options;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _options = options;
    } else {
      _options = {};
      for(k in options) {
        if(k != "__gwt_ObjectId") {
          _options[k] = options[k];
        }
      }
    } 
    this.setOptions(_options);

  }-*/;

  /**
   * Hides this rectangle if set to 
   * <code>false</code>
   * 
   * .
   */ 
  public final native void setVisible(boolean visible)/*-{
    this.setVisible(visible);

  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerBoundsChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "bounds_changed", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "click", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerDblClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "dblclick", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseDown(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mousedown", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseMove(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mousemove", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseOut(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mouseout", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseOver(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mouseover", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMouseUp(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "mouseup", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerRightClick(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "rightclick", _varargs);
  }-*/;

}

