/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;

/**
 * Options defining the properties of a 
 * <code>StreetViewPanorama</code>
 * 
 * object.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class StreetViewPanoramaOptions extends JavaScriptObject {

  /**
   * Callback type for handling asynchronous responses from panoProvider.
   */
  public interface Callback  {

    /**
     * Called by the callback handler
     */ 
    StreetViewPanoramaData handle(String a);
  }

  public static final StreetViewPanoramaOptions create(){
    return JavaScriptObject.createObject().cast();
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected StreetViewPanoramaOptions() {
    /* Java constructor is protected, */
  }

  /**
   * The enabled/disabled state of the address control.
   */ 
  public final native void setAddressControl(boolean addressControl)/*-{
    this.addressControl = addressControl;
  }-*/;

  /**
   * The display options for the address control.
   */ 
  public final native void setAddressControlOptions(StreetViewAddressControlOptions addressControlOptions)/*-{
    var _addressControlOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _addressControlOptions = addressControlOptions;
    } else {
      _addressControlOptions = {};
      for(k in addressControlOptions) {
        if(k != "__gwt_ObjectId") {
          _addressControlOptions[k] = addressControlOptions[k];
        }
      }
    } 
    this.addressControlOptions = _addressControlOptions;
  }-*/;

  /**
   * The enabled/disabled state of click-to-go.
   */ 
  public final native void setClickToGo(boolean clickToGo)/*-{
    this.clickToGo = clickToGo;
  }-*/;

  /**
   * Enables/disables zoom on double click. Disabled by default.
   */ 
  public final native void setDisableDoubleClickZoom(boolean disableDoubleClickZoom)/*-{
    this.disableDoubleClickZoom = disableDoubleClickZoom;
  }-*/;

  /**
   * If 
   * <code>true</code>
   * 
   * , the close button is displayed. Disabled by default.
   */ 
  public final native void setEnableCloseButton(boolean enableCloseButton)/*-{
    this.enableCloseButton = enableCloseButton;
  }-*/;

  /**
   * The enabled/disabled state of the imagery acquisition date control.
   */ 
  public final native void setImageDateControl(boolean imageDateControl)/*-{
    this.imageDateControl = imageDateControl;
  }-*/;

  /**
   * The enabled/disabled state of the links control.
   */ 
  public final native void setLinksControl(boolean linksControl)/*-{
    this.linksControl = linksControl;
  }-*/;

  /**
   * The enabled/disabled state of the pan control.
   */ 
  public final native void setPanControl(boolean panControl)/*-{
    this.panControl = panControl;
  }-*/;

  /**
   * The display options for the pan control.
   */ 
  public final native void setPanControlOptions(PanControlOptions panControlOptions)/*-{
    var _panControlOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _panControlOptions = panControlOptions;
    } else {
      _panControlOptions = {};
      for(k in panControlOptions) {
        if(k != "__gwt_ObjectId") {
          _panControlOptions[k] = panControlOptions[k];
        }
      }
    } 
    this.panControlOptions = _panControlOptions;
  }-*/;

  /**
   * The panorama ID, which should be set when specifying a custom panorama.
   */ 
  public final native void setPano(String pano)/*-{
    this.pano = pano;
  }-*/;

  /**
   * Custom panorama provider, which takes a string pano id and returns an
   * object defining the panorama given that id.  This function must be
   * defined to specify custom panorama imagery.
   */ 
  public final native void setPanoProvider(Callback panoProvider)/*-{
    var _panoProvider = $entry(function(a) {
      return panoProvider.@com.google.maps.gwt.client.StreetViewPanoramaOptions.Callback::handle(Ljava/lang/String;)(a);

    }); 
    this.panoProvider = _panoProvider;
  }-*/;

  /**
   * The 
   * <code>LatLng</code>
   * 
   * position of the Street View panorama.
   */ 
  public final native void setPosition(LatLng position)/*-{
    this.position = position;
  }-*/;

  /**
   * The camera orientation, specified as heading, pitch, and zoom, for the panorama.
   */ 
  public final native void setPov(StreetViewPov pov)/*-{
    this.pov = pov;
  }-*/;

  /**
   * If false, disables scrollwheel zooming in Street View.  The
   * scrollwheel is enabled by default.
   */ 
  public final native void setScrollwheel(boolean scrollwheel)/*-{
    this.scrollwheel = scrollwheel;
  }-*/;

  /**
   * If 
   * <code>true</code>
   * 
   * , the Street View panorama is visible on load.
   */ 
  public final native void setVisible(boolean visible)/*-{
    this.visible = visible;
  }-*/;

  /**
   * The enabled/disabled state of the zoom control.
   */ 
  public final native void setZoomControl(boolean zoomControl)/*-{
    this.zoomControl = zoomControl;
  }-*/;

  /**
   * The display options for the zoom control.
   */ 
  public final native void setZoomControlOptions(ZoomControlOptions zoomControlOptions)/*-{
    var _zoomControlOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _zoomControlOptions = zoomControlOptions;
    } else {
      _zoomControlOptions = {};
      for(k in zoomControlOptions) {
        if(k != "__gwt_ObjectId") {
          _zoomControlOptions[k] = zoomControlOptions[k];
        }
      }
    } 
    this.zoomControlOptions = _zoomControlOptions;
  }-*/;

}

