/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;

/**
 * The properties of the tile set used in a Street View panorama.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class StreetViewTileData extends JavaScriptObject {


  /**
   * Protected constructor avoids default public constructor.
   */
  protected StreetViewTileData() {
    /* Java constructor is protected, */
  }

  /**
   * The heading (in degrees) at the center of the panoramic tiles.
   */ 
  public final native double getCenterHeading()/*-{
    return this.centerHeading;

  }-*/;

  /**
   * The size (in pixels) at which tiles will be rendered. This may not be
   * the native tile image size.
   */ 
  public final native Size getTileSize()/*-{
    return this.tileSize;

  }-*/;

  /**
   * Gets the tile image URL for the specified tile.<br/>
   * <code>pano</code>
   * 
   * is the panorama ID of the Street View tile.<br/>
   * <code>tileZoom</code>
   * 
   * is the zoom level of the tile.<br/>
   * <code>tileX</code>
   * 
   * is the x-coordinate of the tile.<br/>
   * <code>tileY</code>
   * 
   * is the y-coordinate of the tile.<br/> Returns the URL for the tile image.<br/>
   */ 
  public final native String getTileUrl(String pano, double tileZoom, double tileX, double tileY)/*-{
    return this.getTileUrl(pano, tileZoom, tileX, tileY);

  }-*/;

  /**
   * The size (in pixels) of the whole panorama's "world".
   */ 
  public final native Size getWorldSize()/*-{
    return this.worldSize;

  }-*/;

  /**
   * The heading (in degrees) at the center of the panoramic tiles.
   */ 
  public final native void setCenterHeading(double centerHeading)/*-{
    this.centerHeading = centerHeading;
  }-*/;

  /**
   * The size (in pixels) at which tiles will be rendered. This may not be
   * the native tile image size.
   */ 
  public final native void setTileSize(Size tileSize)/*-{
    this.tileSize = tileSize;
  }-*/;

  /**
   * The size (in pixels) of the whole panorama's "world".
   */ 
  public final native void setWorldSize(Size worldSize)/*-{
    this.worldSize = worldSize;
  }-*/;

}

