/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * The valid travel modes that can be specified in a
 * <code>DirectionsRequest</code>
 * 
 * as well as the travel modes returned in a
 * <code>DirectionsStep</code>
 * 
 * .
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class TravelMode extends JavaScriptObject {

  /**
   * Specifies a bicycling directions request.
   */ 
  public static final TravelMode BICYCLING = getBicycling();

  /**
   * Specifies a driving directions request.
   */ 
  public static final TravelMode DRIVING = getDriving();

  /**
   * Specifies a walking directions request.
   */ 
  public static final TravelMode WALKING = getWalking();

  /**
   * Internal registry for value types.
   */ 
  private static Map<String,TravelMode> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final TravelMode fromValue(String value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native TravelMode getBicycling()/*-{
    var instance = { 'value' : $wnd.google.maps.TravelMode.BICYCLING };
    @com.google.maps.gwt.client.TravelMode::register(Lcom/google/maps/gwt/client/TravelMode;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native TravelMode getDriving()/*-{
    var instance = { 'value' : $wnd.google.maps.TravelMode.DRIVING };
    @com.google.maps.gwt.client.TravelMode::register(Lcom/google/maps/gwt/client/TravelMode;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native TravelMode getWalking()/*-{
    var instance = { 'value' : $wnd.google.maps.TravelMode.WALKING };
    @com.google.maps.gwt.client.TravelMode::register(Lcom/google/maps/gwt/client/TravelMode;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(TravelMode value){
    if (registry == null) {
      registry = new HashMap<String, TravelMode>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected TravelMode() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native String getValue()/*-{
    return this.value;
  }-*/;

}

