/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * Identifiers for the zoom control.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class ZoomControlStyle extends JavaScriptObject {

  /**
   * The default zoom control. The control which DEFAULT maps to will vary
   * according to map size and other factors. It may change in future
   * versions of the API.
   */ 
  public static final ZoomControlStyle DEFAULT = getDefault();

  /**
   * The larger control, with the zoom slider in addition to +/- buttons.
   */ 
  public static final ZoomControlStyle LARGE = getLarge();

  /**
   * A small control with buttons to zoom in and out.
   */ 
  public static final ZoomControlStyle SMALL = getSmall();

  /**
   * Internal registry for value types.
   */ 
  private static Map<Double,ZoomControlStyle> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final ZoomControlStyle fromValue(double value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native ZoomControlStyle getDefault()/*-{
    var instance = { 'value' : $wnd.google.maps.ZoomControlStyle.DEFAULT };
    @com.google.maps.gwt.client.ZoomControlStyle::register(Lcom/google/maps/gwt/client/ZoomControlStyle;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native ZoomControlStyle getLarge()/*-{
    var instance = { 'value' : $wnd.google.maps.ZoomControlStyle.LARGE };
    @com.google.maps.gwt.client.ZoomControlStyle::register(Lcom/google/maps/gwt/client/ZoomControlStyle;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native ZoomControlStyle getSmall()/*-{
    var instance = { 'value' : $wnd.google.maps.ZoomControlStyle.SMALL };
    @com.google.maps.gwt.client.ZoomControlStyle::register(Lcom/google/maps/gwt/client/ZoomControlStyle;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(ZoomControlStyle value){
    if (registry == null) {
      registry = new HashMap<Double, ZoomControlStyle>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected ZoomControlStyle() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native double getValue()/*-{
    return this.value;
  }-*/;

}

