/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client.adsense;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * Identifiers used to specify an AdSense For Content format. See <a
 * href="https://google.com/adsense/adformats">https://google.com/adsense/adformats</a>.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class AdFormat extends JavaScriptObject {

  /**
   * A horizontal "banner" ad. (468x60px)
   */ 
  public static final AdFormat BANNER = getBanner();

  /**
   * A small ad. (125x125px)
   */ 
  public static final AdFormat BUTTON = getButton();

  /**
   * A smaller horizontal "banner" ad. (234x60px)
   */ 
  public static final AdFormat HALF_BANNER = getHalfBanner();

  /**
   * A large rectangulare ad. (336x280px)
   */ 
  public static final AdFormat LARGE_RECTANGLE = getLargeRectangle();

  /**
   * A fully horizontal display area. (728x90px)
   */ 
  public static final AdFormat LEADERBOARD = getLeaderboard();

  /**
   * A medium rectangular ad. (300x250px)
   */ 
  public static final AdFormat MEDIUM_RECTANGLE = getMediumRectangle();

  /**
   * A large vertical ad. (120x600px)
   */ 
  public static final AdFormat SKYSCRAPER = getSkyscraper();

  /**
   * A small rectangular ad. (180x150px)
   */ 
  public static final AdFormat SMALL_RECTANGLE = getSmallRectangle();

  /**
   * A smaller square ad. (200x200px)
   */ 
  public static final AdFormat SMALL_SQUARE = getSmallSquare();

  /**
   * A square ad with large type. (250x250px)
   */ 
  public static final AdFormat SQUARE = getSquare();

  /**
   * A medium-sized vertical ad. (120x240px)
   */ 
  public static final AdFormat VERTICAL_BANNER = getVerticalBanner();

  /**
   * A wide, vertical ad using larger type. (160x600px)
   */ 
  public static final AdFormat WIDE_SKYSCRAPER = getWideSkyscraper();

  /**
   * Internal registry for value types.
   */ 
  private static Map<String,AdFormat> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final AdFormat fromValue(String value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native AdFormat getBanner()/*-{
    var instance = { 'value' : $wnd.google.maps.adsense.AdFormat.BANNER };
    @com.google.maps.gwt.client.adsense.AdFormat::register(Lcom/google/maps/gwt/client/adsense/AdFormat;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native AdFormat getButton()/*-{
    var instance = { 'value' : $wnd.google.maps.adsense.AdFormat.BUTTON };
    @com.google.maps.gwt.client.adsense.AdFormat::register(Lcom/google/maps/gwt/client/adsense/AdFormat;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native AdFormat getHalfBanner()/*-{
    var instance = { 'value' : $wnd.google.maps.adsense.AdFormat.HALF_BANNER };
    @com.google.maps.gwt.client.adsense.AdFormat::register(Lcom/google/maps/gwt/client/adsense/AdFormat;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native AdFormat getLargeRectangle()/*-{
    var instance = { 'value' : $wnd.google.maps.adsense.AdFormat.LARGE_RECTANGLE };
    @com.google.maps.gwt.client.adsense.AdFormat::register(Lcom/google/maps/gwt/client/adsense/AdFormat;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native AdFormat getLeaderboard()/*-{
    var instance = { 'value' : $wnd.google.maps.adsense.AdFormat.LEADERBOARD };
    @com.google.maps.gwt.client.adsense.AdFormat::register(Lcom/google/maps/gwt/client/adsense/AdFormat;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native AdFormat getMediumRectangle()/*-{
    var instance = { 'value' : $wnd.google.maps.adsense.AdFormat.MEDIUM_RECTANGLE };
    @com.google.maps.gwt.client.adsense.AdFormat::register(Lcom/google/maps/gwt/client/adsense/AdFormat;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native AdFormat getSkyscraper()/*-{
    var instance = { 'value' : $wnd.google.maps.adsense.AdFormat.SKYSCRAPER };
    @com.google.maps.gwt.client.adsense.AdFormat::register(Lcom/google/maps/gwt/client/adsense/AdFormat;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native AdFormat getSmallRectangle()/*-{
    var instance = { 'value' : $wnd.google.maps.adsense.AdFormat.SMALL_RECTANGLE };
    @com.google.maps.gwt.client.adsense.AdFormat::register(Lcom/google/maps/gwt/client/adsense/AdFormat;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native AdFormat getSmallSquare()/*-{
    var instance = { 'value' : $wnd.google.maps.adsense.AdFormat.SMALL_SQUARE };
    @com.google.maps.gwt.client.adsense.AdFormat::register(Lcom/google/maps/gwt/client/adsense/AdFormat;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native AdFormat getSquare()/*-{
    var instance = { 'value' : $wnd.google.maps.adsense.AdFormat.SQUARE };
    @com.google.maps.gwt.client.adsense.AdFormat::register(Lcom/google/maps/gwt/client/adsense/AdFormat;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native AdFormat getVerticalBanner()/*-{
    var instance = { 'value' : $wnd.google.maps.adsense.AdFormat.VERTICAL_BANNER };
    @com.google.maps.gwt.client.adsense.AdFormat::register(Lcom/google/maps/gwt/client/adsense/AdFormat;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native AdFormat getWideSkyscraper()/*-{
    var instance = { 'value' : $wnd.google.maps.adsense.AdFormat.WIDE_SKYSCRAPER };
    @com.google.maps.gwt.client.adsense.AdFormat::register(Lcom/google/maps/gwt/client/adsense/AdFormat;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(AdFormat value){
    if (registry == null) {
      registry = new HashMap<String, AdFormat>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected AdFormat() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native String getValue()/*-{
    return this.value;
  }-*/;

}

