/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client.drawing;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.maps.gwt.client.Circle;
import com.google.maps.gwt.client.GoogleMap;
import com.google.maps.gwt.client.MVCObject;
import com.google.maps.gwt.client.Marker;
import com.google.maps.gwt.client.Polygon;
import com.google.maps.gwt.client.Polyline;
import com.google.maps.gwt.client.Rectangle;

/**
 * Allows users to draw markers, polygons, polylines, rectangles, and
 * circles on the map. The
 * <code>DrawingManager</code>
 * 
 * 's drawing mode defines the type of overlay that will be created by
 * the user. Adds a control to the map, allowing the user to switch
 * drawing mode.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class DrawingManager extends MVCObject {

  /**
   * This event is fired when the user has finished drawing a circle.
   */
  public interface CirclecompleteHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(Circle circle);
  }

  /**
   * This event is fired when the user has finished drawing a marker.
   */
  public interface MarkercompleteHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(Marker marker);
  }

  /**
   * This event is fired when the user has finished drawing an overlay of any type.
   */
  public interface OverlaycompleteHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(OverlayCompleteEvent event);
  }

  /**
   * This event is fired when the user has finished drawing a polygon.
   */
  public interface PolygoncompleteHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(Polygon polygon);
  }

  /**
   * This event is fired when the user has finished drawing a polyline.
   */
  public interface PolylinecompleteHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(Polyline polyline);
  }

  /**
   * This event is fired when the user has finished drawing a rectangle.
   */
  public interface RectanglecompleteHandler  {

    /**
     * Override to handle event.
     */ 
    void handle(Rectangle rectangle);
  }

  /**
   * Creates a 
   * <code>DrawingManager</code>
   * 
   * that allows users to draw overlays on the map, and switch between the
   * type of overlay to be drawn with a drawing control.
   */ 
  public static native DrawingManager create(DrawingManagerOptions options)/*-{
    var _options;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _options = options;
    } else {
      _options = {};
      for(k in options) {
        if(k != "__gwt_ObjectId") {
          _options[k] = options[k];
        }
      }
    } 
    return new $wnd.google.maps.drawing.DrawingManager(_options);
  }-*/;

  /**
   * Creates a 
   * <code>DrawingManager</code>
   * 
   * that allows users to draw overlays on the map, and switch between the
   * type of overlay to be drawn with a drawing control.
   */ 
  public static native DrawingManager create()/*-{
    return new $wnd.google.maps.drawing.DrawingManager();
  }-*/;


  /**
   * Protected constructor avoids default public constructor.
   */
  protected DrawingManager() {
    /* Java constructor is protected, */
  }

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addCirclecompleteListener(CirclecompleteHandler handler)/*-{
    var _handler = $entry(function(circle) {
      handler.@com.google.maps.gwt.client.drawing.DrawingManager.CirclecompleteHandler::handle(Lcom/google/maps/gwt/client/Circle;)(circle);

    }); 
    $wnd.google.maps.event.addListener(this, "circlecomplete", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addCirclecompleteListenerOnce(CirclecompleteHandler handler)/*-{
    var _handler = $entry(function(circle) {
      handler.@com.google.maps.gwt.client.drawing.DrawingManager.CirclecompleteHandler::handle(Lcom/google/maps/gwt/client/Circle;)(circle);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "circlecomplete", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addMarkercompleteListener(MarkercompleteHandler handler)/*-{
    var _handler = $entry(function(marker) {
      handler.@com.google.maps.gwt.client.drawing.DrawingManager.MarkercompleteHandler::handle(Lcom/google/maps/gwt/client/Marker;)(marker);

    }); 
    $wnd.google.maps.event.addListener(this, "markercomplete", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addMarkercompleteListenerOnce(MarkercompleteHandler handler)/*-{
    var _handler = $entry(function(marker) {
      handler.@com.google.maps.gwt.client.drawing.DrawingManager.MarkercompleteHandler::handle(Lcom/google/maps/gwt/client/Marker;)(marker);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "markercomplete", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addOverlaycompleteListener(OverlaycompleteHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.drawing.DrawingManager.OverlaycompleteHandler::handle(Lcom/google/maps/gwt/client/drawing/OverlayCompleteEvent;)(event);

    }); 
    $wnd.google.maps.event.addListener(this, "overlaycomplete", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addOverlaycompleteListenerOnce(OverlaycompleteHandler handler)/*-{
    var _handler = $entry(function(event) {
      handler.@com.google.maps.gwt.client.drawing.DrawingManager.OverlaycompleteHandler::handle(Lcom/google/maps/gwt/client/drawing/OverlayCompleteEvent;)(event);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "overlaycomplete", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addPolygoncompleteListener(PolygoncompleteHandler handler)/*-{
    var _handler = $entry(function(polygon) {
      handler.@com.google.maps.gwt.client.drawing.DrawingManager.PolygoncompleteHandler::handle(Lcom/google/maps/gwt/client/Polygon;)(polygon);

    }); 
    $wnd.google.maps.event.addListener(this, "polygoncomplete", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addPolygoncompleteListenerOnce(PolygoncompleteHandler handler)/*-{
    var _handler = $entry(function(polygon) {
      handler.@com.google.maps.gwt.client.drawing.DrawingManager.PolygoncompleteHandler::handle(Lcom/google/maps/gwt/client/Polygon;)(polygon);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "polygoncomplete", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addPolylinecompleteListener(PolylinecompleteHandler handler)/*-{
    var _handler = $entry(function(polyline) {
      handler.@com.google.maps.gwt.client.drawing.DrawingManager.PolylinecompleteHandler::handle(Lcom/google/maps/gwt/client/Polyline;)(polyline);

    }); 
    $wnd.google.maps.event.addListener(this, "polylinecomplete", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addPolylinecompleteListenerOnce(PolylinecompleteHandler handler)/*-{
    var _handler = $entry(function(polyline) {
      handler.@com.google.maps.gwt.client.drawing.DrawingManager.PolylinecompleteHandler::handle(Lcom/google/maps/gwt/client/Polyline;)(polyline);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "polylinecomplete", _handler);
  }-*/;

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addRectanglecompleteListener(RectanglecompleteHandler handler)/*-{
    var _handler = $entry(function(rectangle) {
      handler.@com.google.maps.gwt.client.drawing.DrawingManager.RectanglecompleteHandler::handle(Lcom/google/maps/gwt/client/Rectangle;)(rectangle);

    }); 
    $wnd.google.maps.event.addListener(this, "rectanglecomplete", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addRectanglecompleteListenerOnce(RectanglecompleteHandler handler)/*-{
    var _handler = $entry(function(rectangle) {
      handler.@com.google.maps.gwt.client.drawing.DrawingManager.RectanglecompleteHandler::handle(Lcom/google/maps/gwt/client/Rectangle;)(rectangle);

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "rectanglecomplete", _handler);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearCirclecompleteListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "circlecomplete");
  }-*/;

  /**
   * Removes all listeners for all events for the given instance.
   */ 
  public final native void clearInstanceListeners()/*-{
    $wnd.google.maps.event.clearInstanceListeners(this);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearMarkercompleteListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "markercomplete");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearOverlaycompleteListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "overlaycomplete");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearPolygoncompleteListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "polygoncomplete");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearPolylinecompleteListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "polylinecomplete");
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearRectanglecompleteListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "rectanglecomplete");
  }-*/;

  /**
   * Returns the 
   * <code>DrawingManager</code>
   * 
   * 's drawing mode.
   */ 
  public final native OverlayType getDrawingMode()/*-{
    var _retval = this.getDrawingMode();
    var retval = (_retval == undefined) ?
        null : @com.google.maps.gwt.client.drawing.OverlayType::fromValue(Ljava/lang/String;)(_retval);
    return retval;
  }-*/;

  /**
   * Returns the 
   * <code>Map</code>
   * 
   *  to which the 
   * <code>DrawingManager</code>
   * 
   * is attached, which is the 
   * <code>Map</code>
   * 
   * on which the overlays created will be placed.
   */ 
  public final native GoogleMap getMap()/*-{
    return this.getMap();

  }-*/;

  /**
   * Changes the 
   * <code>DrawingManager</code>
   * 
   * 's drawing mode, which defines the type of overlay to be added on the
   * map. Accepted values are
   * <code>MARKER</code>
   * 
   * , 
   * <code>POLYGON</code>
   * 
   * , 
   * <code>POLYLINE</code>
   * 
   * ,
   * <code>RECTANGLE</code>
   * 
   * , 
   * <code>CIRCLE</code>
   * 
   * , or 
   * <code>null</code>
   * 
   * . A drawing mode of 
   * <code>null</code>
   * 
   * means that the user can interact with the map as normal, and clicks
   * do not draw anything.
   */ 
  public final native void setDrawingMode(OverlayType drawingMode)/*-{
    var _drawingMode = drawingMode == undefined ? null : drawingMode.value; 
    this.setDrawingMode(_drawingMode);

  }-*/;

  /**
   * Changes the 
   * <code>DrawingManager</code>
   * 
   * 's drawing mode, which defines the type of overlay to be added on the
   * map. Accepted values are
   * <code>MARKER</code>
   * 
   * , 
   * <code>POLYGON</code>
   * 
   * , 
   * <code>POLYLINE</code>
   * 
   * ,
   * <code>RECTANGLE</code>
   * 
   * , 
   * <code>CIRCLE</code>
   * 
   * , or 
   * <code>null</code>
   * 
   * . A drawing mode of 
   * <code>null</code>
   * 
   * means that the user can interact with the map as normal, and clicks
   * do not draw anything.
   */ 
  public final native void setDrawingMode()/*-{
    this.setDrawingMode();

  }-*/;

  /**
   * Attaches the 
   * <code>DrawingManager</code>
   * 
   * object to the specified
   * <code>Map</code>
   * 
   * .
   */ 
  public final native void setMap(GoogleMap map)/*-{
    this.setMap(map);

  }-*/;

  /**
   * Sets the 
   * <code>DrawingManager</code>
   * 
   * 's options.
   */ 
  public final native void setOptions(DrawingManagerOptions options)/*-{
    var _options;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _options = options;
    } else {
      _options = {};
      for(k in options) {
        if(k != "__gwt_ObjectId") {
          _options[k] = options[k];
        }
      }
    } 
    this.setOptions(_options);

  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerCirclecomplete(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "circlecomplete", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerMarkercomplete(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "markercomplete", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerOverlaycomplete(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "overlaycomplete", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerPolygoncomplete(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "polygoncomplete", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerPolylinecomplete(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "polylinecomplete", _varargs);
  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerRectanglecomplete(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "rectanglecomplete", _varargs);
  }-*/;

}

