/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client.drawing;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.maps.gwt.client.CircleOptions;
import com.google.maps.gwt.client.GoogleMap;
import com.google.maps.gwt.client.MarkerOptions;
import com.google.maps.gwt.client.PolygonOptions;
import com.google.maps.gwt.client.PolylineOptions;
import com.google.maps.gwt.client.RectangleOptions;

/**
 * Options for the drawing manager.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class DrawingManagerOptions extends JavaScriptObject {

  public static final DrawingManagerOptions create(){
    return JavaScriptObject.createObject().cast();
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected DrawingManagerOptions() {
    /* Java constructor is protected, */
  }

  /**
   * Options to apply to any new circles created with this
   * <code>DrawingManager</code>
   * 
   * . The 
   * <code>center</code>
   * 
   *  and 
   * <code>radius</code>
   * 
   * properties are ignored, and the 
   * <code>map</code>
   * 
   * property of a new circle is always set to the 
   * <code>DrawingManager</code>
   * 
   * 's map.
   */ 
  public final native void setCircleOptions(CircleOptions circleOptions)/*-{
    var _circleOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _circleOptions = circleOptions;
    } else {
      _circleOptions = {};
      for(k in circleOptions) {
        if(k != "__gwt_ObjectId") {
          _circleOptions[k] = circleOptions[k];
        }
      }
    } 
    this.circleOptions = _circleOptions;
  }-*/;

  /**
   * The enabled/disabled state of the drawing control. Defaults to
   * <code>true</code>
   * 
   * .
   */ 
  public final native void setDrawingControl(boolean drawingControl)/*-{
    this.drawingControl = drawingControl;
  }-*/;

  /**
   * The display options for the drawing control.
   */ 
  public final native void setDrawingControlOptions(DrawingControlOptions drawingControlOptions)/*-{
    var _drawingControlOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _drawingControlOptions = drawingControlOptions;
    } else {
      _drawingControlOptions = {};
      for(k in drawingControlOptions) {
        if(k != "__gwt_ObjectId") {
          _drawingControlOptions[k] = drawingControlOptions[k];
        }
      }
    } 
    this.drawingControlOptions = _drawingControlOptions;
  }-*/;

  /**
   * The 
   * <code>DrawingManager</code>
   * 
   * 's drawing mode, which defines the type of overlay to be added on the
   * map. Accepted values are
   * <code>MARKER</code>
   * 
   * , 
   * <code>POLYGON</code>
   * 
   * , 
   * <code>POLYLINE</code>
   * 
   * ,
   * <code>RECTANGLE</code>
   * 
   * , 
   * <code>CIRCLE</code>
   * 
   * , or 
   * <code>null</code>
   * 
   * . A drawing mode of 
   * <code>null</code>
   * 
   * means that the user can interact with the map as normal, and clicks
   * do not draw anything.
   */ 
  public final native void setDrawingMode(OverlayType drawingMode)/*-{
    var _drawingMode = drawingMode == undefined ? null : drawingMode.value; 
    this.drawingMode = _drawingMode;
  }-*/;

  /**
   * The 
   * <code>Map</code>
   * 
   *  to which the 
   * <code>DrawingManager</code>
   * 
   * is attached, which is the 
   * <code>Map</code>
   * 
   * on which the overlays created will be placed.
   */ 
  public final native void setMap(GoogleMap map)/*-{
    this.map = map;
  }-*/;

  /**
   * Options to apply to any new markers created with this
   * <code>DrawingManager</code>
   * 
   * . The 
   * <code>position</code>
   * 
   * property is ignored, and the 
   * <code>map</code>
   * 
   * property of a new marker is always set to the
   * <code>DrawingManager</code>
   * 
   * 's map.
   */ 
  public final native void setMarkerOptions(MarkerOptions markerOptions)/*-{
    var _markerOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _markerOptions = markerOptions;
    } else {
      _markerOptions = {};
      for(k in markerOptions) {
        if(k != "__gwt_ObjectId") {
          _markerOptions[k] = markerOptions[k];
        }
      }
    } 
    this.markerOptions = _markerOptions;
  }-*/;

  /**
   * Options to apply to any new polygons created with this
   * <code>DrawingManager</code>
   * 
   * . The 
   * <code>paths</code>
   * 
   * property is ignored, and the 
   * <code>map</code>
   * 
   * property of a new polygon is always set to the
   * <code>DrawingManager</code>
   * 
   * 's map.
   */ 
  public final native void setPolygonOptions(PolygonOptions polygonOptions)/*-{
    var _polygonOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _polygonOptions = polygonOptions;
    } else {
      _polygonOptions = {};
      for(k in polygonOptions) {
        if(k != "__gwt_ObjectId") {
          _polygonOptions[k] = polygonOptions[k];
        }
      }
    } 
    this.polygonOptions = _polygonOptions;
  }-*/;

  /**
   * Options to apply to any new polylines created with this
   * <code>DrawingManager</code>
   * 
   * . The 
   * <code>path</code>
   * 
   * property is ignored, and the 
   * <code>map</code>
   * 
   * property of a new polyline is always set to the
   * <code>DrawingManager</code>
   * 
   * 's map.
   */ 
  public final native void setPolylineOptions(PolylineOptions polylineOptions)/*-{
    var _polylineOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _polylineOptions = polylineOptions;
    } else {
      _polylineOptions = {};
      for(k in polylineOptions) {
        if(k != "__gwt_ObjectId") {
          _polylineOptions[k] = polylineOptions[k];
        }
      }
    } 
    this.polylineOptions = _polylineOptions;
  }-*/;

  /**
   * Options to apply to any new rectangles created with this
   * <code>DrawingManager</code>
   * 
   * . The 
   * <code>bounds</code>
   * 
   * property is ignored, and the 
   * <code>map</code>
   * 
   * property of a new rectangle is always set to the
   * <code>DrawingManager</code>
   * 
   * 's map.
   */ 
  public final native void setRectangleOptions(RectangleOptions rectangleOptions)/*-{
    var _rectangleOptions;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _rectangleOptions = rectangleOptions;
    } else {
      _rectangleOptions = {};
      for(k in rectangleOptions) {
        if(k != "__gwt_ObjectId") {
          _rectangleOptions[k] = rectangleOptions[k];
        }
      }
    } 
    this.rectangleOptions = _rectangleOptions;
  }-*/;

}

