/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client.drawing;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * The types of overlay that may be created by the
 * <code>DrawingManager</code>
 * 
 * .
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class OverlayType extends JavaScriptObject {

  /**
   * Specifies that the 
   * <code>DrawingManager</code>
   * 
   * creates circles, and that the overlay given in the 
   * <code>overlaycomplete</code>
   * 
   * event is a circle.
   */ 
  public static final OverlayType CIRCLE = getCircle();

  /**
   * Specifies that the 
   * <code>DrawingManager</code>
   * 
   * creates markers, and that the overlay given in the 
   * <code>overlaycomplete</code>
   * 
   * event is a marker.
   */ 
  public static final OverlayType MARKER = getMarker();

  /**
   * Specifies that the 
   * <code>DrawingManager</code>
   * 
   * creates polygons, and that the overlay given in the 
   * <code>overlaycomplete</code>
   * 
   * event is a polygon.
   */ 
  public static final OverlayType POLYGON = getPolygon();

  /**
   * Specifies that the 
   * <code>DrawingManager</code>
   * 
   * creates polylines, and that the overlay given in the 
   * <code>overlaycomplete</code>
   * 
   * event is a polyline.
   */ 
  public static final OverlayType POLYLINE = getPolyline();

  /**
   * Specifies that the 
   * <code>DrawingManager</code>
   * 
   * creates rectangles, and that the overlay given in the 
   * <code>overlaycomplete</code>
   * 
   * event is a rectangle.
   */ 
  public static final OverlayType RECTANGLE = getRectangle();

  /**
   * Internal registry for value types.
   */ 
  private static Map<String,OverlayType> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final OverlayType fromValue(String value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native OverlayType getCircle()/*-{
    var instance = { 'value' : $wnd.google.maps.drawing.OverlayType.CIRCLE };
    @com.google.maps.gwt.client.drawing.OverlayType::register(Lcom/google/maps/gwt/client/drawing/OverlayType;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native OverlayType getMarker()/*-{
    var instance = { 'value' : $wnd.google.maps.drawing.OverlayType.MARKER };
    @com.google.maps.gwt.client.drawing.OverlayType::register(Lcom/google/maps/gwt/client/drawing/OverlayType;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native OverlayType getPolygon()/*-{
    var instance = { 'value' : $wnd.google.maps.drawing.OverlayType.POLYGON };
    @com.google.maps.gwt.client.drawing.OverlayType::register(Lcom/google/maps/gwt/client/drawing/OverlayType;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native OverlayType getPolyline()/*-{
    var instance = { 'value' : $wnd.google.maps.drawing.OverlayType.POLYLINE };
    @com.google.maps.gwt.client.drawing.OverlayType::register(Lcom/google/maps/gwt/client/drawing/OverlayType;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native OverlayType getRectangle()/*-{
    var instance = { 'value' : $wnd.google.maps.drawing.OverlayType.RECTANGLE };
    @com.google.maps.gwt.client.drawing.OverlayType::register(Lcom/google/maps/gwt/client/drawing/OverlayType;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(OverlayType value){
    if (registry == null) {
      registry = new HashMap<String, OverlayType>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected OverlayType() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native String getValue()/*-{
    return this.value;
  }-*/;

}

