/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client.places;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArrayString;
import com.google.gwt.dom.client.InputElement;
import com.google.maps.gwt.client.LatLngBounds;
import com.google.maps.gwt.client.MVCObject;

/**
 * A service to provide Place predictions based on a user's text input.
 * It attaches to an input element of type
 * <code>text</code>
 * 
 * , and listens for text entry in that field. The list of predictions
 * is presented as a drop-down list, and is updated as text is entered.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class Autocomplete extends MVCObject {

  /**
   * This event is fired when a 
   * <code>PlaceResult</code>
   * 
   * is made available for a Place the user has selected. <br>If the user
   * enters the name of a Place that was not suggested by the control and
   * presses the Enter key, a
   * <code>place_changed</code>
   * 
   * event will be fired that contains the user input in the 
   * <code>name</code>
   * 
   * property, with no other properties defined.
   */
  public interface PlaceChangedHandler  {

    /**
     * Override to handle event.
     */ 
    void handle();
  }

  /**
   * Creates a new instance of 
   * <code>Autocomplete</code>
   * 
   * that attaches to the specified input text field with the given options.
   */ 
  public static native Autocomplete create(InputElement inputField, AutocompleteOptions opts)/*-{
    var _opts;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _opts = opts;
    } else {
      _opts = {};
      for(k in opts) {
        if(k != "__gwt_ObjectId") {
          _opts[k] = opts[k];
        }
      }
    } 
    return new $wnd.google.maps.places.Autocomplete(inputField, _opts);
  }-*/;

  /**
   * Creates a new instance of 
   * <code>Autocomplete</code>
   * 
   * that attaches to the specified input text field with the given options.
   */ 
  public static native Autocomplete create(InputElement inputField)/*-{
    return new $wnd.google.maps.places.Autocomplete(inputField);
  }-*/;


  /**
   * Protected constructor avoids default public constructor.
   */
  protected Autocomplete() {
    /* Java constructor is protected, */
  }

  /**
   * Adds the given listener function to the given event name for the
   * given object instance. Returns an identifier for this listener that
   * can be used with removeListener().
   */ 
  public final native void addPlaceChangedListener(PlaceChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.places.Autocomplete.PlaceChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListener(this, "place_changed", _handler);
  }-*/;

  /**
   * Like addListener, but the handler removes itself after handling the first event.
   */ 
  public final native void addPlaceChangedListenerOnce(PlaceChangedHandler handler)/*-{
    var _handler = $entry(function() {
      handler.@com.google.maps.gwt.client.places.Autocomplete.PlaceChangedHandler::handle()();

    }); 
    $wnd.google.maps.event.addListenerOnce(this, "place_changed", _handler);
  }-*/;

  /**
   * Removes all listeners for all events for the given instance.
   */ 
  public final native void clearInstanceListeners()/*-{
    $wnd.google.maps.event.clearInstanceListeners(this);
  }-*/;

  /**
   * Removes all listeners for the given event for the given instance.
   */ 
  public final native void clearPlaceChangedListeners()/*-{
    $wnd.google.maps.event.clearListeners(this, "place_changed");
  }-*/;

  /**
   * Returns the bounds to which predictions are biased.
   */ 
  public final native LatLngBounds getBounds()/*-{
    return this.getBounds();

  }-*/;

  /**
   * Returns the details of the Place selected by the user, or 
   * <code>null</code>
   * 
   * if no Place has been selected yet.
   */ 
  public final native PlaceResult getPlace()/*-{
    return this.getPlace();

  }-*/;

  /**
   * Sets the preferred area within which to return Place results. Results
   * are biased towards, but not restricted to, this area.
   */ 
  public final native void setBounds(LatLngBounds bounds)/*-{
    this.setBounds(bounds);

  }-*/;

  /**
   * Sets the types of predictions to be returned. Supported types are '
   * <code>establishment</code>
   * 
   * ' for businesses and '
   * <code>geocode</code>
   * 
   * ' for addresses. If no type is specified, both types will be returned.
   */ 
  public final native void setTypes(JsArrayString types)/*-{
    this.setTypes(types);

  }-*/;

  /**
   * Triggers the given event. All arguments after eventName are passed as
   * arguments to the listeners.
   */ 
  public final native void triggerPlaceChanged(JavaScriptObject... varargs)/*-{
    var _varargs =
        @com.google.maps.gwt.client.ArrayHelper::toJsArray([Lcom/google/gwt/core/client/JavaScriptObject;)(varargs); 
    $wnd.google.maps.event.trigger(this, "place_changed", _varargs);
  }-*/;

}

