/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client.places;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArray;
import com.google.gwt.core.client.JsArrayString;
import com.google.maps.gwt.client.GeocoderAddressComponent;

/**
 * Defines information about a Place.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class PlaceResult extends JavaScriptObject {

  public static final PlaceResult create(){
    return JavaScriptObject.createObject().cast();
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected PlaceResult() {
    /* Java constructor is protected, */
  }

  /**
   * The collection of address components for this Place's location.
   */ 
  public final native JsArray<GeocoderAddressComponent> getAddressComponents()/*-{
    return this.address_components;

  }-*/;

  /**
   * The Place's full address.
   */ 
  public final native String getFormattedAddress()/*-{
    return this.formatted_address;

  }-*/;

  /**
   * The Place's phone number, formatted according to the <a
   * href="http://en.wikipedia.org/wiki/Local_conventions_for_writing_telephone_numbers">
   * number's regional convention</a>.
   */ 
  public final native String getFormattedPhoneNumber()/*-{
    return this.formatted_phone_number;

  }-*/;

  /**
   * The Place's geometry-related information.
   */ 
  public final native PlaceGeometry getGeometry()/*-{
    return this.geometry;

  }-*/;

  /**
   * Attribution text to be displayed for this Place result.
   */ 
  public final native String getHtmlAttributions()/*-{
    return this.html_attributions;

  }-*/;

  /**
   * URL to an image resource that can be used to represent this Place's category.
   */ 
  public final native String getIcon()/*-{
    return this.icon;

  }-*/;

  /**
   * A unique identifier denoting this Place. This identifier may not be
   * used to retrieve information about this Place, and to verify the
   * identity of a Place across separate searches. As
   * <code>id</code>
   * 
   * s can occasionally change, it is recommended that the stored 
   * <code>id</code>
   * 
   * for a Place be compared with the 
   * <code>id</code>
   * 
   * returned in later Details requests for the same Place, and updated if necessary.
   */ 
  public final native String getId()/*-{
    return this.id;

  }-*/;

  /**
   * The Place's phone number in international format. International
   * format includes the country code, and is prefixed with the plus (+)
   * sign.
   */ 
  public final native String getInternationalPhoneNumber()/*-{
    return this.international_phone_number;

  }-*/;

  /**
   * The Place's name. Note: In the case of user entered Places, this is
   * the raw text, as typed by the user. Please exercise caution when
   * using this data, as malicious users may try to use it as a vector for
   * code injection attacks (See <a href="http://en.wikipedia.org/wiki/Code_injection">
   * http://en.wikipedia.org/wiki/Code_injection</a>).
   */ 
  public final native String getName()/*-{
    return this.name;

  }-*/;

  /**
   * The Place's rating, from 0.0 to 5.0, based on user reviews.
   */ 
  public final native double getRating()/*-{
    return this.rating;

  }-*/;

  /**
   * An opaque string that may be used to retrieve up-to-date information
   * about this Place (via
   * <code><a href="#PlacesService">
   * PlacesService</a>.getDetails()</code>
   * 
   * ).
   * <code>reference</code>
   * 
   * contains a unique token that you can use to retrieve additional
   * information about this Place in a Place Details request. You can
   * store this token and use it at any time in future to refresh cached
   * data about this Place, but the same token is not guaranteed to be
   * returned for any given Place across different searches.
   */ 
  public final native String getReference()/*-{
    return this.reference;

  }-*/;

  /**
   * An array of types for this Place (e.g., 
   * <code>["political",&nbsp;
   * "locality"]</code>
   * 
   * or
   * <code>["restaurant", "establishment"]</code>
   * 
   * ).
   */ 
  public final native JsArrayString getTypes()/*-{
    return this.types;

  }-*/;

  /**
   * URL of the associated Google Place Page.
   */ 
  public final native String getUrl()/*-{
    return this.url;

  }-*/;

  /**
   * A fragment of the Place's address for disambiguation (usually street
   * name and locality).
   */ 
  public final native String getVicinity()/*-{
    return this.vicinity;

  }-*/;

  /**
   * The authoritative website for this Place, such as a business' homepage.
   */ 
  public final native String getWebsite()/*-{
    return this.website;

  }-*/;

}

