/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client.places;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArrayString;
import com.google.maps.gwt.client.LatLng;
import com.google.maps.gwt.client.LatLngBounds;

/**
 * A Place search query to be sent to the 
 * <code>PlacesService</code>
 * 
 * .
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class PlaceSearchRequest extends JavaScriptObject {

  public static final PlaceSearchRequest create(){
    return JavaScriptObject.createObject().cast();
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected PlaceSearchRequest() {
    /* Java constructor is protected, */
  }

  /**
   * The bounds within which to search for Places. Both
   * <code>location</code>
   * 
   *  and 
   * <code>radius</code>
   * 
   * will be ignored if
   * <code>bounds</code>
   * 
   * is set.
   */ 
  public final native void setBounds(LatLngBounds bounds)/*-{
    this.bounds = bounds;
  }-*/;

  /**
   * A term to be matched against all available fields, including but not
   * limited to name, type, and address, as well as customer reviews and
   * other third-party content.
   */ 
  public final native void setKeyword(String keyword)/*-{
    this.keyword = keyword;
  }-*/;

  /**
   * The location around which to search for Places.
   */ 
  public final native void setLocation(LatLng location)/*-{
    this.location = location;
  }-*/;

  /**
   * Restricts the Place search results to Places that include this text in the name.
   */ 
  public final native void setName(String name)/*-{
    this.name = name;
  }-*/;

  /**
   * The distance from the given location within which to search for
   * Places, in meters. The maximum allowed value is 50&thinsp;000.
   */ 
  public final native void setRadius(double radius)/*-{
    this.radius = radius;
  }-*/;

  /**
   * Restricts the Place search results to Places with a type matching at
   * least one of the specified types in this array. Valid types are given
   * <a href="/maps/documentation/places/supported_types">here</a>.
   */ 
  public final native void setTypes(JsArrayString types)/*-{
    this.types = types;
  }-*/;

}

