/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client.places;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArray;
import com.google.gwt.dom.client.DivElement;
import com.google.maps.gwt.client.GoogleMap;

/**
 * Contains methods related to searching for Places and retrieving
 * details about a Place.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class PlacesService extends JavaScriptObject {

  /**
   * Callback type for handling asynchronous responses from search.
   */
  public interface Callback  {

    /**
     * Called by the callback handler
     */ 
    void handle(JsArray<PlaceResult> a, PlacesServiceStatus b);
  }

  /**
   * Callback type for handling asynchronous responses from getDetails.
   */
  public interface GetDetailsCallback  {

    /**
     * Called by the callback handler
     */ 
    void handle(PlaceResult a, PlacesServiceStatus b);
  }

  /**
   * Creates a new instance of the 
   * <code>PlacesService</code>
   * 
   * that renders attributions in the specified container.
   */ 
  public static native PlacesService create(DivElement attrContainer)/*-{
    return new $wnd.google.maps.places.PlacesService(attrContainer);
  }-*/;

  /**
   * Creates a new instance of the 
   * <code>PlacesService</code>
   * 
   * that renders attributions in the specified container.
   */ 
  public static native PlacesService create(GoogleMap attrContainer)/*-{
    return new $wnd.google.maps.places.PlacesService(attrContainer);
  }-*/;


  /**
   * Protected constructor avoids default public constructor.
   */
  protected PlacesService() {
    /* Java constructor is protected, */
  }

  /**
   * Retrieves details about the Place identified by the given reference.
   */ 
  public final native void getDetails(PlaceDetailsRequest request, GetDetailsCallback callback)/*-{
    var _request;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _request = request;
    } else {
      _request = {};
      for(k in request) {
        if(k != "__gwt_ObjectId") {
          _request[k] = request[k];
        }
      }
    } 
    var _callback = $entry(function(a, _b) {
      var b = (_b == undefined) ?
          null : @com.google.maps.gwt.client.places.PlacesServiceStatus::fromValue(Ljava/lang/String;)(_b); 
      callback.@com.google.maps.gwt.client.places.PlacesService.GetDetailsCallback::handle(Lcom/google/maps/gwt/client/places/PlaceResult;Lcom/google/maps/gwt/client/places/PlacesServiceStatus;)(a,b);

    }); 
    this.getDetails(_request, _callback);

  }-*/;

  /**
   * Retrieves a list of Places in a given area. The 
   * <code>PlaceResult</code>
   * 
   * s passed to the callback are stripped-down versions of a full
   * PlaceResult. A more detailed
   * <code>PlaceResult</code>
   * 
   * for each Place can be obtained by sending a Place Details request
   * with the desired Place's
   * <code>reference</code>
   * 
   * value.
   */ 
  public final native void search(PlaceSearchRequest request, Callback callback)/*-{
    var _request;
    if(@com.google.gwt.core.client.GWT::isScript()()) {
      _request = request;
    } else {
      _request = {};
      for(k in request) {
        if(k != "__gwt_ObjectId") {
          _request[k] = request[k];
        }
      }
    } 
    var _callback = $entry(function(a, _b) {
      var b = (_b == undefined) ?
          null : @com.google.maps.gwt.client.places.PlacesServiceStatus::fromValue(Ljava/lang/String;)(_b); 
      callback.@com.google.maps.gwt.client.places.PlacesService.Callback::handle(Lcom/google/gwt/core/client/JsArray;Lcom/google/maps/gwt/client/places/PlacesServiceStatus;)(a,b);

    }); 
    this.search(_request, _callback);

  }-*/;

}

