/*
 * Copyright 2011 The Google Web Toolkit Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.maps.gwt.client.places;

import com.google.gwt.core.client.JavaScriptObject;
import java.util.HashMap;
import java.util.Map;

/**
 * The status returned by the 
 * <code>PlacesService</code>
 * 
 * on the completion of its searches.
 *
 * THIS SOURCE CODE IS GENERATED, DO NOT MODIFY
 */
public class PlacesServiceStatus extends JavaScriptObject {

  /**
   * This request was invalid.
   */ 
  public static final PlacesServiceStatus INVALID_REQUEST = getInvalidRequest();

  /**
   * The response contains a valid result.
   */ 
  public static final PlacesServiceStatus OK = getOk();

  /**
   * The application has gone over its request quota.
   */ 
  public static final PlacesServiceStatus OVER_QUERY_LIMIT = getOverQueryLimit();

  /**
   * The application is not allowed to use the 
   * <code>PlacesService</code>
   * 
   * .
   */ 
  public static final PlacesServiceStatus REQUEST_DENIED = getRequestDenied();

  /**
   * The 
   * <code>PlacesService</code>
   * 
   * request could not be processed due to a server error. The request may
   * succeed if you try again.
   */ 
  public static final PlacesServiceStatus UNKNOWN_ERROR = getUnknownError();

  /**
   * No result was found for this request.
   */ 
  public static final PlacesServiceStatus ZERO_RESULTS = getZeroResults();

  /**
   * Internal registry for value types.
   */ 
  private static Map<String,PlacesServiceStatus> registry;

  /**
   * Access the enum instance using the underlying value of the type.
   */ 
  public static final PlacesServiceStatus fromValue(String value){
    return registry.get(value);
  }

  /**
   * Internal initialization method.
   */ 
  private static final native PlacesServiceStatus getInvalidRequest()/*-{
    var instance = { 'value' : $wnd.google.maps.places.PlacesServiceStatus.INVALID_REQUEST };
    @com.google.maps.gwt.client.places.PlacesServiceStatus::register(Lcom/google/maps/gwt/client/places/PlacesServiceStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native PlacesServiceStatus getOk()/*-{
    var instance = { 'value' : $wnd.google.maps.places.PlacesServiceStatus.OK };
    @com.google.maps.gwt.client.places.PlacesServiceStatus::register(Lcom/google/maps/gwt/client/places/PlacesServiceStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native PlacesServiceStatus getOverQueryLimit()/*-{
    var instance = { 'value' : $wnd.google.maps.places.PlacesServiceStatus.OVER_QUERY_LIMIT };
    @com.google.maps.gwt.client.places.PlacesServiceStatus::register(Lcom/google/maps/gwt/client/places/PlacesServiceStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native PlacesServiceStatus getRequestDenied()/*-{
    var instance = { 'value' : $wnd.google.maps.places.PlacesServiceStatus.REQUEST_DENIED };
    @com.google.maps.gwt.client.places.PlacesServiceStatus::register(Lcom/google/maps/gwt/client/places/PlacesServiceStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native PlacesServiceStatus getUnknownError()/*-{
    var instance = { 'value' : $wnd.google.maps.places.PlacesServiceStatus.UNKNOWN_ERROR };
    @com.google.maps.gwt.client.places.PlacesServiceStatus::register(Lcom/google/maps/gwt/client/places/PlacesServiceStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal initialization method.
   */ 
  private static final native PlacesServiceStatus getZeroResults()/*-{
    var instance = { 'value' : $wnd.google.maps.places.PlacesServiceStatus.ZERO_RESULTS };
    @com.google.maps.gwt.client.places.PlacesServiceStatus::register(Lcom/google/maps/gwt/client/places/PlacesServiceStatus;)(instance);
    return instance;
  }-*/;

  /**
   * Internal registration of type for future access.
   */ 
  private static final void register(PlacesServiceStatus value){
    if (registry == null) {
      registry = new HashMap<String, PlacesServiceStatus>();
    }
    registry.put(value.getValue(),value);
  }


  /**
   * Protected constructor avoids default public constructor.
   */
  protected PlacesServiceStatus() {
    /* Java constructor is protected, */
  }

  /**
   * Access the underlying value of the type.
   */ 
  public final native String getValue()/*-{
    return this.value;
  }-*/;

}

